@@ -1,8 +1,9 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
+#include <clocale>
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
@@ -149,6 +150,10 @@ void Message::Initialize(int argc, char **argv)
   HPDDM::Option& opt = *HPDDM::Option::get();
   opt.parse(argc, argv, _commRank == 0);
 #endif
+  // make sure to use the "C" locale; in particular this ensures that we will
+  // use a dot for for the decimal separator when writing ASCII mesh files
+  std::setlocale(LC_ALL, "C");
+  std::setlocale(LC_NUMERIC, "C");
 }
 
 void Message::Finalize()
@@ -302,7 +307,7 @@ void Message::Error(const char *fmt, ...)
 
 void Message::Warning(const char *fmt, ...)
 {
-  if((_commRank && _isCommWorld) || _verbosity < 2) return;
+  if(_verbosity < 2) return;
   char str[1024];
   va_list args;
   va_start(args, fmt);
@@ -320,10 +325,10 @@ void Message::Warning(const char *fmt, ...)
     if(!streamIsFile(stdout) && streamIsVT100(stdout)){
       c0 = "\33[35m"; c1 = "\33[0m";  // magenta
     }
-    if(_isCommWorld)
-      fprintf(stdout, "%sWarning : %s%s\n", c0, str, c1);
-    else
+    if(_commSize > 1)
       fprintf(stdout, "%sWarning : [rank %3d] %s%s\n", c0, _commRank, str, c1);
+    else
+      fprintf(stdout, "%sWarning : %s%s\n", c0, str, c1);
     fflush(stdout);
   }
 }
@@ -1160,6 +1165,8 @@ void Message::ExchangeOnelabParameter(Constant *c, fmap &fopt, cmap &copt)
       ps[0].setAttribute("Closed", copt["Closed"][0]);
     if(noClosed && fopt.count("Closed"))
       ps[0].setAttribute("Closed", fopt["Closed"][0] ? "1" : "0");
+    if(copt.count("NumberFormat"))
+      ps[0].setAttribute("NumberFormat", copt["NumberFormat"][0]);
     _setStandardOptions(&ps[0], fopt, copt);
     _onelabClient->set(ps[0]);
   }
