@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -98,6 +98,7 @@ struct Group {
   int     Num,  Type, FunctionType, SuppListType, SuppListType2;
   List_T *InitialList, *InitialSuppList, *InitialSuppList2;
   List_T *ExtendedList, *ExtendedSuppList, *ExtendedSuppList2;
+  int     InitialListGroupIndex, InitialSuppListGroupIndex, InitialSuppList2GroupIndex;
   std::multimap<int, TwoInt> ExtendedListForSearch;
   struct  MovingBand2D *MovingBand2D;
 };
@@ -157,6 +158,7 @@ struct MovingBand2D {
 #define SUPPLIST_ONNEGATIVESIDEOF 5
 #define SUPPLIST_INSUPPORT        6
 #define SUPPLIST_CONNECTEDTO      7
+#define SUPPLIST_DISJOINTOF       8
 
 
 /* ------------------------------------------------------------------------ */
@@ -463,6 +465,8 @@ struct FunctionActive {
       double *mi, *bi, *ci, *di;  /* Akima */
     } Interpolation;
     struct {
+      List_T *RegionList;
+      int     RegionCurrent;
       double  Value;
     } SurfaceArea;
     struct {
@@ -1012,6 +1016,8 @@ struct Operation {
       double  Shift_r, Shift_i;
       int     FilterExpressionIndex;
       List_T *RationalCoefsNum, *RationalCoefsDen;
+      List_T *ApplyResolventRealFreqs;
+      int DefineOtherSystemIndex;
     } EigenSolve;
     struct {
       List_T  *Expressions;
@@ -1135,6 +1141,7 @@ struct Operation {
     } Generate_MH_Moving_S;
     struct {
       int     GroupIndex;
+      int     NumListOfRHS;
     } Generate;
     struct {
       int     GroupIndex;
@@ -1362,6 +1369,8 @@ struct IterativeLoopSystem {
 #define OPERATION_CLEARVECTORS             115
 #define OPERATION_GATHERVARIABLES          116
 #define OPERATION_SCATTERVARIABLES         117
+#define OPERATION_EXIT                     118
+#define OPERATION_GENERATELISTOFRHS        119
 
 /* ChangeOfState.Type */
 #define CHANGEOFSTATE_NOCHANGE              0
@@ -1439,7 +1448,7 @@ struct PostQuantityTerm {
 /* ------------------------------------------------------------------------ */
 
 struct PostOperation {
-  char    *Name, *AppendString;
+  char    *Name, *AppendString, *Comma;
   bool     Hidden;
   int      PostProcessingIndex, Format;
   List_T  *PostSubOperation;
@@ -1454,7 +1463,8 @@ struct PostOperation {
 struct PostSubOperation {
   int    PostQuantityIndex[2], PostQuantitySupport[2];
   int    Type, SubType, CombinationType;
-  int    Depth, Skin, Smoothing, Dimension, Comma, HarmonicToTime, CatFile;
+  int    Depth, Skin, Smoothing, Dimension, HarmonicToTime, CatFile;
+  char  *Comma;
   int    TimeToHarmonic;
   int    FourierTransform;
   int    Format, Adapt, Sort, Iso, NoNewLine, NoTitle, DecomposeInSimplex;
@@ -1713,7 +1723,7 @@ struct Element {
 } ;
 
 /* Element.Type */
-#define POINT            (1<<0)
+#define POINT_ELEMENT    (1<<0) // POINT is used in the Windows API
 
 #define LINE             (1<<1)
 #define TRIANGLE         (1<<2)
@@ -1753,10 +1763,10 @@ struct Element {
 // #define PYRAMID_4        (1<<32)
 
 /* Adapt.Type */
-#define P1 1
-#define P2 2
-#define H1 3
-#define H2 4
+#define ADAPT_P1 1
+#define ADAPT_P2 2
+#define ADAPT_H1 3
+#define ADAPT_H2 4
 
 struct Geo_Node {
   int     Num ;
