@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -67,6 +67,7 @@ struct StringXDefine  FunctionForGroup_SuppList[] = {
   {"OnNegativeSideOf", SUPPLIST_ONNEGATIVESIDEOF},
   {"InSupport"       , SUPPLIST_INSUPPORT},
   {"ConnectedTo"     , SUPPLIST_CONNECTEDTO},
+  {"DisjointOf"      , SUPPLIST_DISJOINTOF},
   {NULL              , 0}
 } ;
 
@@ -112,7 +113,7 @@ struct StringXDefine  Integration_SubType[] = {
 } ;
 
 struct StringXDefine  Element_Type[] = {
-  {"Point"          , POINT},
+  {"Point"          , POINT_ELEMENT},
   {"Line"           , LINE},
   {"Line2"          , LINE_2},
   {"Line3"          , LINE_3},
@@ -394,10 +395,10 @@ struct StringXDefine  PostSubOperation_FormatTag[] = {
 } ;
 
 struct StringXDefine  PostSubOperation_AdaptationType[] = {
-  {"P1"     , P1},
-  {"H1"     , H1},
-  {"H2"     , H2},
-  {NULL     , P1}
+  {"P1"     , ADAPT_P1},
+  {"H1"     , ADAPT_H1},
+  {"H2"     , ADAPT_H2},
+  {NULL     , ADAPT_P1}
 } ;
 
 struct StringXDefine  PostSubOperation_SortType[] = {
@@ -414,7 +415,7 @@ struct StringXDefine  PostSubOperation_SortType[] = {
 
 struct DefineXFunction  FunctionForGauss[] = {
 #if defined(HAVE_KERNEL)
-  {POINT          , (CAST)Gauss_Point},
+  {POINT_ELEMENT  , (CAST)Gauss_Point},
   {LINE           , (CAST)Gauss_Line},
   {LINE_2         , (CAST)Gauss_Line},
   {LINE_3         , (CAST)Gauss_Line},
@@ -448,7 +449,7 @@ struct DefineXFunction  FunctionForGauss[] = {
   {PYRAMID_3      , (CAST)Gauss_Pyramid},
   //{PYRAMID_4      , (CAST)Gauss_Pyramid},
 #else
-  {POINT          , NULL},
+  {POINT_ELEMENT  , NULL},
   {LINE           , NULL},
   {LINE_2         , NULL},
   {LINE_3         , NULL},
@@ -498,14 +499,23 @@ struct DefineXFunction  FunctionForSingularGauss[] = {
 
 struct DefineXFunction  FunctionForGaussLegendre[] = {
 #if defined(HAVE_KERNEL)
-  {POINT          , (CAST)Gauss_Point},
+  {POINT_ELEMENT  , (CAST)Gauss_Point},
   {LINE           , (CAST)Gauss_Line},
+  {LINE_2         , (CAST)Gauss_Line},
   {TRIANGLE       , (CAST)GaussLegendre_Triangle},
+  {TRIANGLE_2     , (CAST)GaussLegendre_Triangle},
   {QUADRANGLE     , (CAST)GaussLegendre_Quadrangle},
+  {QUADRANGLE_2   , (CAST)GaussLegendre_Quadrangle},
   {TETRAHEDRON    , (CAST)GaussLegendre_Tetrahedron},
+  {TETRAHEDRON_2  , (CAST)GaussLegendre_Tetrahedron},
   {HEXAHEDRON     , (CAST)GaussLegendre_Hexahedron},
+  {HEXAHEDRON_2   , (CAST)GaussLegendre_Hexahedron},
+  {PRISM          , (CAST)Gauss_Prism},
+  {PRISM_2        , (CAST)Gauss_Prism},
+  {PYRAMID        , (CAST)Gauss_Pyramid},
+  {PYRAMID_2      , (CAST)Gauss_Pyramid},
 #else
-  {POINT          , NULL},
+  {POINT_ELEMENT  , NULL},
   {LINE           , NULL},
   {TRIANGLE       , NULL},
   {QUADRANGLE     , NULL},
@@ -515,7 +525,7 @@ struct DefineXFunction  FunctionForGaussLegendre[] = {
   {0              , 0}
 } ;
 
-#define POI  POINT
+#define POI  POINT_ELEMENT
 #define LIN  LINE | LINE_2 | LINE_3 | LINE_4
 #define TRI  TRIANGLE | TRIANGLE_2 | TRIANGLE_3 | TRIANGLE_4
 #define QUA  QUADRANGLE | QUADRANGLE_2 | QUADRANGLE_2_8N | QUADRANGLE_3 | QUADRANGLE_4
@@ -533,7 +543,7 @@ struct StringX3Function3Nbr  BF_Function[] = {
   {"BF_Node_1N", (CAST)BF_Node,
                  (CAST)BF_GradNode,    (CAST)BF_Zero, 1., ALL, 0 },
   {"BF_Node_2E", (CAST)BF_Node_2E,
-                 (CAST)BF_GradNode_2E, (CAST)BF_Zero, 2., ALL, 0 },
+                 (CAST)BF_GradNode_2E, (CAST)BF_Zero, 2., LIN|TRI|TET, 0 },
   {"BF_Node_2F", (CAST)BF_Node_2F,
                  (CAST)BF_GradNode_2F, (CAST)BF_Zero, 2., QUA|HEX/*|PRI|PYR*/, 0 },
   {"BF_Node_2V", (CAST)BF_Node_2V,
@@ -552,7 +562,7 @@ struct StringX3Function3Nbr  BF_Function[] = {
   {"BF_GradNode_1N", (CAST)BF_GradNode,
                      (CAST)BF_Zero, (CAST)BF_Node,    0., ALL, 0 },
   {"BF_GradNode_2E", (CAST)BF_GradNode_2E,
-                     (CAST)BF_Zero, (CAST)BF_Node_2E, 1., ALL, 0 },
+                     (CAST)BF_Zero, (CAST)BF_Node_2E, 1., LIN|TRI|TET, 0 },
   {"BF_GradNode_2F", (CAST)BF_GradNode_2F,
                      (CAST)BF_Zero, (CAST)BF_Node_2F, 1., QUA|HEX/*|PRI|PYR*/, 0 },
   {"BF_GradNode_2V", (CAST)BF_GradNode_2V,
@@ -606,108 +616,108 @@ struct StringX3Function3Nbr  BF_Function[] = {
   {"BF_Edge_1E",   (CAST)BF_Edge,
                    (CAST)BF_CurlEdge,      (CAST)BF_Zero, 0.5, ALL, 1 },
   {"BF_Edge_2E",   (CAST)BF_Edge_2E,
-                   (CAST)BF_CurlEdge_2E,   (CAST)BF_Zero, 1.,  ALL, 0 },
+                   (CAST)BF_CurlEdge_2E,   (CAST)BF_Zero, 1.,  LIN|TRI|TET, 0 },
   {"BF_Edge_2F",   (CAST)BF_Edge_2F,
                    (CAST)BF_CurlEdge_2F,   (CAST)BF_Zero, 1.,  ALL, 0 },
   {"BF_Edge_2V",   (CAST)BF_Edge_2V,
                    (CAST)BF_CurlEdge_2V,   (CAST)BF_Zero, 1.,  ALL, 0 },
   {"BF_Edge_3E",   (CAST)BF_Edge_3E,
-                   (CAST)BF_CurlEdge_3E,   (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                   (CAST)BF_CurlEdge_3E,   (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_Edge_3F_a", (CAST)BF_Edge_3F_a,
-                   (CAST)BF_CurlEdge_3F_a, (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                   (CAST)BF_CurlEdge_3F_a, (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_Edge_3F_b", (CAST)BF_Edge_3F_b,
-                   (CAST)BF_CurlEdge_3F_b, (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                   (CAST)BF_CurlEdge_3F_b, (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_Edge_3F_c", (CAST)BF_Edge_3F_c,
-                   (CAST)BF_CurlEdge_3F_c, (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                   (CAST)BF_CurlEdge_3F_c, (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_Edge_3V",   (CAST)BF_Edge_3V,
-                   (CAST)BF_CurlEdge_3V,   (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                   (CAST)BF_CurlEdge_3V,   (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_Edge_4E",   (CAST)BF_Edge_4E,
                    (CAST)BF_CurlEdge_4E,   (CAST)BF_Zero, 2.,  ALL, 0 },
   {"BF_Edge_4F",   (CAST)BF_Edge_4F,
-                   (CAST)BF_CurlEdge_4F,   (CAST)BF_Zero, 2.,  TRI|QUA|TET|HEX|PRI, 0 },
+                   (CAST)BF_CurlEdge_4F,   (CAST)BF_Zero, 2.,  LIN|TRI|TET, 0 },
   {"BF_Edge_4V",   (CAST)BF_Edge_4V,
-                   (CAST)BF_CurlEdge_4V,   (CAST)BF_Zero, 2.,  TRI|QUA|TET|HEX|PRI, 0 },
+                   (CAST)BF_CurlEdge_4V,   (CAST)BF_Zero, 2.,  LIN|TRI|TET, 0 },
 
   {"BF_CurlEdge",      (CAST)BF_CurlEdge,
                        (CAST)BF_Zero, (CAST)BF_Edge,      0., ALL, 1 },
   {"BF_CurlEdge_1E",   (CAST)BF_CurlEdge,
                        (CAST)BF_Zero, (CAST)BF_Edge,      0., ALL, 0 },
   {"BF_CurlEdge_2E",   (CAST)BF_CurlEdge_2E,
-                       (CAST)BF_Zero, (CAST)BF_Edge_2E,   0., ALL, 0 },
+                       (CAST)BF_Zero, (CAST)BF_Edge_2E,   0., LIN|TRI|TET, 0 },
   {"BF_CurlEdge_2F",   (CAST)BF_CurlEdge_2F,
                        (CAST)BF_Zero, (CAST)BF_Edge_2F,   0., ALL, 0 },
   {"BF_CurlEdge_2V",   (CAST)BF_CurlEdge_2V,
                        (CAST)BF_Zero, (CAST)BF_Edge_2V,   0., ALL, 0 },
   {"BF_CurlEdge_3E",   (CAST)BF_CurlEdge_3E,
-                       (CAST)BF_Zero, (CAST)BF_Edge_3E,   1., TRI|QUA|TET|HEX|PRI, 0 },
+                       (CAST)BF_Zero, (CAST)BF_Edge_3E,   1., LIN|TRI|TET, 0 },
   {"BF_CurlEdge_3F_a", (CAST)BF_CurlEdge_3F_a,
-                       (CAST)BF_Zero, (CAST)BF_Edge_3F_a, 1., TRI|QUA|TET|HEX|PRI, 0 },
+                       (CAST)BF_Zero, (CAST)BF_Edge_3F_a, 1., LIN|TRI|TET, 0 },
   {"BF_CurlEdge_3F_b", (CAST)BF_CurlEdge_3F_b,
-                       (CAST)BF_Zero, (CAST)BF_Edge_3F_b, 1., TRI|QUA|TET|HEX|PRI, 0 },
+                       (CAST)BF_Zero, (CAST)BF_Edge_3F_b, 1., LIN|TRI|TET, 0 },
   {"BF_CurlEdge_3F_c", (CAST)BF_CurlEdge_3F_c,
-                       (CAST)BF_Zero, (CAST)BF_Edge_3F_c, 1., TRI|QUA|TET|HEX|PRI, 0 },
+                       (CAST)BF_Zero, (CAST)BF_Edge_3F_c, 1., LIN|TRI|TET, 0 },
   {"BF_CurlEdge_3V",   (CAST)BF_CurlEdge_3V,
-                       (CAST)BF_Zero, (CAST)BF_Edge_3V,   1., TRI|QUA|TET|HEX|PRI, 0 },
+                       (CAST)BF_Zero, (CAST)BF_Edge_3V,   1., LIN|TRI|TET, 0 },
   {"BF_CurlEdge_4E",   (CAST)BF_CurlEdge_4E,
                        (CAST)BF_Zero, (CAST)BF_Edge_4E,   1., ALL, 0 },
   {"BF_CurlEdge_4F",   (CAST)BF_CurlEdge_4F,
-                       (CAST)BF_Zero, (CAST)BF_Edge_4F,   1., TRI|QUA|TET|HEX|PRI, 0 },
+                       (CAST)BF_Zero, (CAST)BF_Edge_4F,   1., LIN|TRI|TET, 0 },
   {"BF_CurlEdge_4V",   (CAST)BF_CurlEdge_4V,
-                       (CAST)BF_Zero, (CAST)BF_Edge_4V,   1., TRI|QUA|TET|HEX|PRI, 0 },
+                       (CAST)BF_Zero, (CAST)BF_Edge_4V,   1., LIN|TRI|TET, 0 },
 
   {"BF_GroupOfEdges",      (CAST)BF_GroupOfEdges,
                            (CAST)BF_CurlGroupOfEdges,      (CAST)BF_Zero, 0.5, ALL, 1 },
   {"BF_GroupOfEdges_1E",   (CAST)BF_GroupOfEdges,
                            (CAST)BF_CurlGroupOfEdges,      (CAST)BF_Zero, 0.5, ALL, 0 },
   {"BF_GroupOfEdges_2E",   (CAST)BF_GroupOfEdges_2E,
-                           (CAST)BF_CurlGroupOfEdges_2E,   (CAST)BF_Zero, 1.,  ALL, 0 },
+                           (CAST)BF_CurlGroupOfEdges_2E,   (CAST)BF_Zero, 1.,  LIN|TRI|TET, 0 },
   {"BF_GroupOfEdges_2F",   (CAST)BF_GroupOfEdges_2F,
                            (CAST)BF_CurlGroupOfEdges_2F,   (CAST)BF_Zero, 1.,  ALL, 0 },
   {"BF_GroupOfEdges_2V",   (CAST)BF_GroupOfEdges_2V,
                            (CAST)BF_CurlGroupOfEdges_2V,   (CAST)BF_Zero, 1.,  ALL, 0 },
   {"BF_GroupOfEdges_3E",   (CAST)BF_GroupOfEdges_3E,
-                           (CAST)BF_CurlGroupOfEdges_3E,   (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                           (CAST)BF_CurlGroupOfEdges_3E,   (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_GroupOfEdges_3F_a", (CAST)BF_GroupOfEdges_3F_a,
-                           (CAST)BF_CurlGroupOfEdges_3F_a, (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                           (CAST)BF_CurlGroupOfEdges_3F_a, (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_GroupOfEdges_3F_b", (CAST)BF_GroupOfEdges_3F_b,
-                           (CAST)BF_CurlGroupOfEdges_3F_b, (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                           (CAST)BF_CurlGroupOfEdges_3F_b, (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_GroupOfEdges_3F_c", (CAST)BF_GroupOfEdges_3F_c,
-                           (CAST)BF_CurlGroupOfEdges_3F_c, (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                           (CAST)BF_CurlGroupOfEdges_3F_c, (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_GroupOfEdges_3V",   (CAST)BF_GroupOfEdges_3V,
-                           (CAST)BF_CurlGroupOfEdges_3V,   (CAST)BF_Zero, 1.5, TRI|QUA|TET|HEX|PRI, 0 },
+                           (CAST)BF_CurlGroupOfEdges_3V,   (CAST)BF_Zero, 1.5, LIN|TRI|TET, 0 },
   {"BF_GroupOfEdges_4E",   (CAST)BF_GroupOfEdges_4E,
                            (CAST)BF_CurlGroupOfEdges_4E,   (CAST)BF_Zero, 2.,  ALL, 0 },
   {"BF_GroupOfEdges_4F",   (CAST)BF_GroupOfEdges_4F,
-                           (CAST)BF_CurlGroupOfEdges_4F,   (CAST)BF_Zero, 2.,  TRI|QUA|TET|HEX|PRI, 0 },
+                           (CAST)BF_CurlGroupOfEdges_4F,   (CAST)BF_Zero, 2.,  LIN|TRI|TET, 0 },
   {"BF_GroupOfEdges_4V",   (CAST)BF_GroupOfEdges_4V,
-                           (CAST)BF_CurlGroupOfEdges_4V,   (CAST)BF_Zero, 2.,  TRI|QUA|TET|HEX|PRI, 0 },
+                           (CAST)BF_CurlGroupOfEdges_4V,   (CAST)BF_Zero, 2.,  LIN|TRI|TET, 0 },
 
   {"BF_CurlGroupOfEdges",      (CAST)BF_CurlGroupOfEdges,
                                (CAST)BF_Zero, (CAST)BF_GroupOfEdges,      0., ALL, 1 },
   {"BF_CurlGroupOfEdges_1E",   (CAST)BF_CurlGroupOfEdges,
                                (CAST)BF_Zero, (CAST)BF_GroupOfEdges,      0., ALL, 0 },
   {"BF_CurlGroupOfEdges_2E",   (CAST)BF_CurlGroupOfEdges_2E,
-                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_2E,   0., ALL, 0 },
+                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_2E,   0., LIN|TRI|TET, 0 },
   {"BF_CurlGroupOfEdges_2F",   (CAST)BF_CurlGroupOfEdges_2F,
                                (CAST)BF_Zero, (CAST)BF_GroupOfEdges_2F,   0., ALL, 0 },
   {"BF_CurlGroupOfEdges_2V",   (CAST)BF_CurlGroupOfEdges_2V,
                                (CAST)BF_Zero, (CAST)BF_GroupOfEdges_2V,   0., ALL, 0 },
   {"BF_CurlGroupOfEdges_3E",   (CAST)BF_CurlGroupOfEdges_3E,
-                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3E,   1., TRI|QUA|TET|HEX|PRI, 0 },
+                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3E,   1., LIN|TRI|TET, 0 },
   {"BF_CurlGroupOfEdges_3F_a", (CAST)BF_CurlGroupOfEdges_3F_a,
-                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3F_a, 1., TRI|QUA|TET|HEX|PRI, 0 },
+                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3F_a, 1., LIN|TRI|TET, 0 },
   {"BF_CurlGroupOfEdges_3F_b", (CAST)BF_CurlGroupOfEdges_3F_b,
-                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3F_b, 1., TRI|QUA|TET|HEX|PRI, 0 },
+                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3F_b, 1., LIN|TRI|TET, 0 },
   {"BF_CurlGroupOfEdges_3F_c", (CAST)BF_CurlGroupOfEdges_3F_c,
-                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3F_c, 1., TRI|QUA|TET|HEX|PRI, 0 },
+                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3F_c, 1., LIN|TRI|TET, 0 },
   {"BF_CurlGroupOfEdges_3V",   (CAST)BF_CurlGroupOfEdges_3V,
-                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3V,   1., TRI|QUA|TET|HEX|PRI, 0 },
+                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_3V,   1., LIN|TRI|TET, 0 },
   {"BF_CurlGroupOfEdges_4E",   (CAST)BF_CurlGroupOfEdges_4E,
                                (CAST)BF_Zero, (CAST)BF_GroupOfEdges_4E,   1., ALL, 0 },
   {"BF_CurlGroupOfEdges_4F",   (CAST)BF_CurlGroupOfEdges_4F,
-                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_4F,   1., TRI|QUA|TET|HEX|PRI, 0 },
+                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_4F,   1., LIN|TRI|TET, 0 },
   {"BF_CurlGroupOfEdges_4V",   (CAST)BF_CurlGroupOfEdges_4V,
-                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_4V,   1., TRI|QUA|TET|HEX|PRI, 0 },
+                               (CAST)BF_Zero, (CAST)BF_GroupOfEdges_4V,   1., LIN|TRI|TET, 0 },
 
 
   // H(curl, perp) basis Functions and their curls
@@ -864,9 +874,9 @@ struct StringX3Function3Nbr  BF_Function[] = {
   {"BF_NodeY" , (CAST)BF_NodeY , (CAST)BF_NodeY_D1 , (CAST)BF_NodeY_D2 , 1. , ALL, 0 },
   {"BF_NodeZ" , (CAST)BF_NodeZ , (CAST)BF_NodeZ_D1 , (CAST)BF_NodeZ_D2 , 1. , ALL, 0 },
 
-  {"BF_NodeX_2E" , (CAST)BF_NodeX_2E , (CAST)BF_NodeX_D1_2E , (CAST)BF_NodeX_D2_2E , 2. , ALL, 0 },
-  {"BF_NodeY_2E" , (CAST)BF_NodeY_2E , (CAST)BF_NodeY_D1_2E , (CAST)BF_NodeY_D2_2E , 2. , ALL, 0 },
-  {"BF_NodeZ_2E" , (CAST)BF_NodeZ_2E , (CAST)BF_NodeZ_D1_2E , (CAST)BF_NodeZ_D2_2E , 2. , ALL, 0 },
+  {"BF_NodeX_2E" , (CAST)BF_NodeX_2E , (CAST)BF_NodeX_D1_2E , (CAST)BF_NodeX_D2_2E , 2. , LIN|TRI|TET|HEX, 0 },
+  {"BF_NodeY_2E" , (CAST)BF_NodeY_2E , (CAST)BF_NodeY_D1_2E , (CAST)BF_NodeY_D2_2E , 2. , LIN|TRI|TET|HEX, 0 },
+  {"BF_NodeZ_2E" , (CAST)BF_NodeZ_2E , (CAST)BF_NodeZ_D1_2E , (CAST)BF_NodeZ_D2_2E , 2. , LIN|TRI|TET|HEX, 0 },
 
   {"BF_NodeX_2F" , (CAST)BF_NodeX_2F , (CAST)BF_NodeX_D1_2F , (CAST)BF_NodeX_D2_2F , 2. , QUA|HEX/*|PRI*/, 0 },
   {"BF_NodeY_2F" , (CAST)BF_NodeY_2F , (CAST)BF_NodeY_D1_2F , (CAST)BF_NodeY_D2_2F , 2. , QUA|HEX/*|PRI*/, 0 },
@@ -1251,9 +1261,9 @@ struct StringXFunction2Nbr  F_Function[] = {    /* #Par #Arg */
   {"pnm"               , (CAST)F_pnm              ,   0,   3 },
   {"unm"               , (CAST)F_unm              ,   0,   3 },
   {"snm"               , (CAST)F_snm              ,   0,   3 },
-  {"Xnm"               , (CAST)F_Xnm              ,   0,   4 },
-  {"Ynm"               , (CAST)F_Ynm              ,   0,   4 },
-  {"Znm"               , (CAST)F_Znm              ,   0,   4 },
+  {"Xnm"               , (CAST)F_Xnm              ,   0,   5 },
+  {"Ynm"               , (CAST)F_Ynm              ,   0,   5 },
+  {"Znm"               , (CAST)F_Znm              ,   0,   5 },
   {"Mnm"               , (CAST)F_Mnm              ,   0,   5 },
   {"Nnm"               , (CAST)F_Nnm              ,   0,   5 },
 
@@ -1293,6 +1303,7 @@ struct StringXFunction2Nbr  F_Function[] = {    /* #Par #Arg */
   {"GradVectorField",        (CAST)F_GradVectorField       ,   -1,   -1 },
   {"GradComplexScalarField", (CAST)F_GradComplexScalarField,   -1,   -1 },
   {"GradComplexVectorField", (CAST)F_GradComplexVectorField,   -1,   -1 },
+  {"Distance",           (CAST)F_Distance          ,    1,   1 },
 
   // F_DiffGeom
   {"Hodge",              (CAST)F_Hodge             ,    1,   2 },
