@@ -1,19 +1,22 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <getdp@onelab.info>.
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
-#ifndef _EIGEN_SOLVE_H_
-#define _EIGEN_SOLVE_H_
+#ifndef EIGEN_SOLVE_H
+#define EIGEN_SOLVE_H
 
 #include "DofData.h"
 
 void EigenSolve(struct DofData * DofData_P, int NumEigenvalues,
                 double shift_r, double shift_i, int FilterExpressionIndex,
-                List_T *RationalCoefsNum, List_T *RationalCoefsDen);
+                List_T *RationalCoefsNum, List_T *RationalCoefsDen, 
+                List_T *ApplyResolventRealFreqs, struct DofData * DofData_P2);
 void EigenSolve_ARPACK(struct DofData * DofData_P, int NumEigenvalues,
                        double shift_r, double shift_i, int FilterExpressionIndex);
 void EigenSolve_SLEPC(struct DofData * DofData_P, int NumEigenvalues,
                       double shift_r, double shift_i, int FilterExpressionIndex,
-                      List_T *RationalCoefsNum, List_T *RationalCoefsDen);
+                      List_T *RationalCoefsNum, List_T *RationalCoefsDen,
+                      List_T *ApplyResolventRealFreqs, struct DofData * DofData_P2);
+
 #endif
