@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -46,9 +46,10 @@ int Check_IsEntityInExtendedGroup(struct Group * Group_P, int Entity, int Flag)
       Generate_ExtendedGroup(Group_P) ;
     return((!Group_P->InitialList ||
 	    (List_Search(Group_P->ExtendedList, &Entity, fcmp_int))) &&
-           // assumes that SuppListType is SUPPLIST_NOT:
 	   (!Group_P->InitialSuppList ||
-	    (! List_Search(Group_P->ExtendedSuppList, &Entity, fcmp_int)))) ;
+            ((Group_P->SuppListType == SUPPLIST_CONNECTEDTO) ||
+             // anything remaining in ExtendedSuppList is checked as an exclusion
+             !List_Search(Group_P->ExtendedSuppList, &Entity, fcmp_int)))) ;
 
   case ELEMENTSOF :  case EDGESOFTREEIN :  case FACETSOFTREEIN :
     if (!Group_P->ExtendedList) Generate_ExtendedGroup(Group_P) ;
@@ -56,7 +57,7 @@ int Check_IsEntityInExtendedGroup(struct Group * Group_P, int Entity, int Flag)
 
   case GROUPSOFNODESOF :  case GROUPSOFEDGESOF : case GROUPSOFFACETSOF :
   case REGION :  case GROUPOFREGIONSOF :  case GLOBAL :
-    return( (Flag)? List_Search(Group_P->InitialList, &Entity, fcmp_int) : 1 ) ;
+    return( (Flag) ? List_Search(Group_P->InitialList, &Entity, fcmp_int) : 1 ) ;
 
   case GROUPSOFEDGESONNODESOF :
     if (!Group_P->InitialSuppList){
@@ -76,18 +77,37 @@ int Check_IsEntityInExtendedGroup(struct Group * Group_P, int Entity, int Flag)
 
 void Generate_ExtendedGroup(struct Group * Group_P)
 {
+  // struct Group * RegionGroup_P = NULL;
+  // bool isInitialListEL = false;
+  // bool isInitialSuppListEL = false;
+  // bool isInitialSuppList2EL = false;
 
-  Message::Info("  Generate ExtendedGroup '%s' (%s)", Group_P->Name,
-            Get_StringForDefine(FunctionForGroup_Type, Group_P->FunctionType)) ;
+  Message::Info("  Generate ExtendedGroup '%s' (%s, %s)", Group_P->Name,
+                Get_StringForDefine(FunctionForGroup_Type, Group_P->FunctionType),
+                Get_StringForDefine(FunctionForGroup_SuppList, Group_P->SuppListType)) ;
 
   switch (Group_P->FunctionType) {
 
   case NODESOF :  case EDGESOF :  case FACETSOF :  case VOLUMESOF :
   case GROUPOFREGIONSOF :
-    Generate_ElementaryEntities(Group_P->InitialList,
-				&Group_P->ExtendedList, Group_P->FunctionType) ;
-    Generate_ElementaryEntities(Group_P->InitialSuppList,
-				&Group_P->ExtendedSuppList, Group_P->FunctionType) ;
+    if(Group_P->FunctionType == EDGESOF &&
+       Group_P->SuppListType == SUPPLIST_CONNECTEDTO) {
+      Generate_ElementaryEntities(Group_P->InitialSuppList,
+                                  &Group_P->ExtendedSuppList, NODESOF) ;
+      Generate_EdgesConnectedToNodesOf(Group_P->InitialList,
+                                       Group_P->ExtendedSuppList,
+                                       &Group_P->ExtendedList) ;
+    }
+    else {
+      Generate_ElementaryEntities(Group_P->InitialList,
+                                  &Group_P->ExtendedList, Group_P->FunctionType) ;
+      Generate_ElementaryEntities(Group_P->InitialSuppList,
+                                  &Group_P->ExtendedSuppList, Group_P->FunctionType) ;
+      if(Group_P->SuppListType != SUPPLIST_NONE &&
+         Group_P->SuppListType != SUPPLIST_NOT){
+        Message::Warning("Unhandled group modifier %d", Group_P->SuppListType);
+      }
+    }
     break ;
 
   case GROUPSOFEDGESONNODESOF :
@@ -119,10 +139,31 @@ void Generate_ExtendedGroup(struct Group * Group_P)
     break ;
 
   case EDGESOFTREEIN :
-    Geo_GenerateEdgesOfTree(Group_P->InitialList, Group_P->InitialSuppList,
-                            Group_P->InitialSuppList2, Group_P->SuppListType2,
-			    &Group_P->ExtendedList) ;
+    {
+    List_T * List0 = Group_P->InitialList;
+    List_T * List1 = Group_P->InitialSuppList;
+    List_T * List2 = Group_P->InitialSuppList2;
+    bool isElementList0 = false;
+    bool isElementList1 = false;
+    bool isElementList2 = false;
+
+    if( Group_P->InitialListGroupIndex != -1){
+      struct Group * RegionGroup_P = (struct Group *)
+        List_Pointer(Problem_S.Group, Group_P->InitialListGroupIndex);
+      if( RegionGroup_P->Type == ELEMENTLIST) {
+        if (!RegionGroup_P->ExtendedList) Generate_ExtendedGroup(RegionGroup_P);
+        isElementList0 = true;
+        List0 = RegionGroup_P->ExtendedList;
+      }
+    } // similar operation could be done for List1 and List2 if need be
+
+    Geo_GenerateEdgesOfTree(List0, isElementList0,
+                            List1, isElementList1,
+                            List2, isElementList2,
+                            Group_P->SuppListType2, &Group_P->ExtendedList) ;
+
     Geo_AddGroupForPRE(Group_P->Num) ;
+    }
     break ;
 
   case FACETSOFTREEIN :
@@ -480,6 +521,35 @@ void Generate_GroupsOfFacets(List_T * InitialList,
   */
 }
 
+/* ------------------------------------------------------------------------ */
+/*  G e n e r a t e _ E d g e s C o n n e c t e d T o N o d e s O f         */
+/* ------------------------------------------------------------------------ */
+
+void Generate_EdgesConnectedToNodesOf(List_T *InitialList,
+                                      List_T *NodeList,
+                                      List_T **ExtendedList)
+{
+  Tree_T *Entity_Tr = Tree_Create(sizeof(int), fcmp_int) ;
+  int Nbr_Element = Geo_GetNbrGeoElements();
+  for(int i_Element = 0; i_Element < Nbr_Element; i_Element++) {
+    struct Geo_Element *Geo_Element = Geo_GetGeoElement(i_Element);
+    if(List_Search(InitialList, &Geo_Element->Region, fcmp_int)) {
+      if (Geo_Element->NbrEdges == 0)  Geo_CreateEdgesOfElement(Geo_Element) ;
+      for (int i_Entity = 0 ; i_Entity < Geo_Element->NbrEdges ; i_Entity++) {
+        int *Num_Nodes = Geo_GetNodesOfEdgeInElement(Geo_Element, i_Entity) ;
+        int N1 = Geo_Element->NumNodes[abs(Num_Nodes[0]) - 1];
+        int N2 = Geo_Element->NumNodes[abs(Num_Nodes[1]) - 1];
+        if(List_Search(NodeList, &N1, fcmp_absint) ^
+           List_Search(NodeList, &N2, fcmp_absint)) {
+          Tree_Add(Entity_Tr, &Geo_Element->NumEdges[i_Entity]);
+        }
+      }
+    }
+  }
+  *ExtendedList = Tree2List(Entity_Tr) ;
+  Tree_Delete(Entity_Tr) ;
+}
+
 /* ------------------------------------------------------------------------ */
 /*  G e n e r a t e _ E l e m e n t s                                       */
 /* ------------------------------------------------------------------------ */
@@ -779,7 +849,7 @@ void GenEle_OnPositiveSideOf::add_FacetsOnSur(struct Geo_Element * geoElement)
       X /= geoElement->NbrNodes; Y /= geoElement->NbrNodes; Z /= geoElement->NbrNodes;
 
       entityOnSur.X[0] = X; entityOnSur.X[1] = Y; entityOnSur.X[2] = Z;
-      if(geoElement->Type == POINT){
+      if(geoElement->Type == POINT_ELEMENT){
         // FIXME: hack so that we can use OnPositiveSide of for line elements
         // connected to points, in 3D models. Assumes that the lines are not in
         // the z=0 plane.
@@ -1124,6 +1194,11 @@ void  Generate_Elements(List_T * InitialList,
 
   Nbr_Element = Geo_GetNbrGeoElements() ;
 
+  // TODO: Add a warning when the initial group is not empty (i.e. there are
+  // some candidate elements) but and Generate_Elements() returns an empty list
+  // of elements? Cf. debugging of OnPositiveSideOf of a curve located on the
+  // boundary :-)
+
   switch (Type_SuppList) {
 
   case SUPPLIST_ONONESIDEOF :
@@ -1132,16 +1207,16 @@ void  Generate_Elements(List_T * InitialList,
       Generate_GroupsOfNodes(InitialSuppList, &ExtendedSuppList) ;
 
       for (i_Element = 0 ; i_Element < Nbr_Element ; i_Element++) {
-	GeoElement = Geo_GetGeoElement(i_Element) ;
-	if (List_Search(InitialList, &GeoElement->Region, fcmp_int)) {
-	  Nbr_Node = GeoElement->NbrNodes ;
-	  for (i_Node = 0 ; i_Node < Nbr_Node ; i_Node++)
-	    if (List_Search(ExtendedSuppList,
+        GeoElement = Geo_GetGeoElement(i_Element) ;
+        if (List_Search(InitialList, &GeoElement->Region, fcmp_int)) {
+          Nbr_Node = GeoElement->NbrNodes ;
+          for (i_Node = 0 ; i_Node < Nbr_Node ; i_Node++)
+            if (List_Search(ExtendedSuppList,
 			    &(GeoElement->NumNodes[i_Node]), fcmp_int)) {
 	      Tree_Add(Entity_Tr, &GeoElement->Num) ;
 	      break ;  // at least one node of element is on surface Supp
-	    }
-	}
+            }
+        }
       }
       /* + ne conserver que certains des elements qui viennent d'etre groupes ... ! */
       // Now: rather done with SUPPLIST_ONPOSITIVESIDEOF (to be unified later)
@@ -1152,6 +1227,35 @@ void  Generate_Elements(List_T * InitialList,
     Tree_Delete(Entity_Tr) ;
     break ;
 
+  case SUPPLIST_DISJOINTOF :
+    Entity_Tr = Tree_Create(sizeof(int), fcmp_int) ;
+    if (List_Nbr(InitialSuppList)) {
+
+      Generate_ElementaryEntities(InitialSuppList,
+                                  &ExtendedSuppList, NODESOF) ;
+
+      for (i_Element = 0 ; i_Element < Nbr_Element ; i_Element++) {
+        GeoElement = Geo_GetGeoElement(i_Element) ;
+        if (List_Search(InitialList, &GeoElement->Region, fcmp_int)) {
+          Nbr_Node = GeoElement->NbrNodes ;
+          bool touch = false;
+          for (i_Node = 0 ; i_Node < Nbr_Node ; i_Node++) {
+            if (List_Search(ExtendedSuppList,
+                            &(GeoElement->NumNodes[i_Node]), fcmp_int)) {
+              touch = true;
+              break;
+            }
+          }
+          if(!touch) Tree_Add(Entity_Tr, &GeoElement->Num) ;
+        }
+      }
+      List_Delete(ExtendedSuppList) ;
+    }
+
+    *ExtendedList = Tree2List(Entity_Tr) ;
+    Tree_Delete(Entity_Tr) ;
+    break ;
+
   case SUPPLIST_ONNEGATIVESIDEOF :
     side = -1;
   case SUPPLIST_ONPOSITIVESIDEOF :
@@ -1215,5 +1319,4 @@ void  Generate_Elements(List_T * InitialList,
     break ;
 
   }
-
 }
