@@ -1,10 +1,10 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <getdp@onelab.info>.
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
-#ifndef _EXTENDED_GROUP_H_
-#define _EXTENDED_GROUP_H_
+#ifndef EXTENDED_GROUP_H
+#define EXTENDED_GROUP_H
 
 #include "ProData.h"
 #include "ListUtils.h"
@@ -17,6 +17,8 @@ void Generate_GroupsOfNodes(List_T * InitialList, List_T ** ExtendedList) ;
 void Generate_GroupsOfEdges(List_T * InitialList, int Type_SuppList,
 			    List_T * InitialSuppList, List_T ** ExtendedList) ;
 void Generate_GroupsOfFacets(List_T * InitialList, List_T ** ExtendedList) ;
+void Generate_EdgesConnectedToNodesOf(List_T *InitialList, List_T *NodeList,
+                                      List_T ** ExtendedList) ;
 void Generate_Elements(List_T * InitialList,
                        int Type_SuppList, List_T * InitialSuppList,
                        int Type_SuppList2, List_T * InitialSuppList2,
