@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -187,7 +187,7 @@ void Geo_CloseFile(void)
 int Geo_GetNbNodesPerElement(int Type)
 {
   switch(Type){
-  case POINT         : return 1;
+  case POINT_ELEMENT : return 1;
 
   case LINE          : return 2;
   case TRIANGLE      : return 3;
@@ -234,7 +234,7 @@ int Geo_GetNbNodesPerElement(int Type)
 int Geo_GetDimOfElement(int Type)
 {
   switch(Type){
-  case POINT         : return 0;
+  case POINT_ELEMENT : return 0;
 
   case LINE          : return 1;
   case TRIANGLE      : return 2;
@@ -281,7 +281,7 @@ void Geo_ReverseElement(Geo_Element *Geo_Element)
 {
   int tmp;
   switch(Geo_Element->Type){
-  case POINT :
+  case POINT_ELEMENT :
     break;
   case LINE :
   case LINE_2 :
@@ -395,6 +395,25 @@ static std::string ExtractDoubleQuotedString(const char *str, int len)
   return ret;
 }
 
+static void Geo_SnapNodes(struct GeoData * GeoData_P)
+{
+  // 2D meshes used for axisymmetric calculations should have the minimum
+  // x-coordinate *exactly* equal to 0: snap x coordinate of all vertices of 2D
+  // meshes with fabs(x) < 1e-13 to 0.
+  if(GeoData_P->Dimension != DIM_2D || fabs(GeoData_P->Xmin) > 1e-13) return;
+  int snaps = 0;
+  for(int i = 0; i < List_Nbr(GeoData_P->Nodes); i++) {
+    Geo_Node *n = (Geo_Node*)List_Pointer(GeoData_P->Nodes, i);
+    if(fabs(n->x) < 1e-13) {
+      n->x = 0.;
+      snaps++;
+    }
+  }
+  if(snaps)
+    Message::Info("Snapped x coordinate of %d node%s to 0", snaps,
+                  (snaps > 1) ? "s" : "");
+}
+
 static void Geo_ReadFileWithGmsh(struct GeoData * GeoData_P)
 {
 #if defined(HAVE_GMSH)
@@ -458,6 +477,7 @@ static void Geo_ReadFileWithGmsh(struct GeoData * GeoData_P)
   else
     GeoData_P->Dimension = DIM_0D;
 
+
   GeoData_P->CharacteristicLength =
   sqrt(SQU(GeoData_P->Xmax - GeoData_P->Xmin) +
        SQU(GeoData_P->Ymax - GeoData_P->Ymin) +
@@ -544,6 +564,8 @@ static void Geo_ReadFileWithGmsh(struct GeoData * GeoData_P)
     }
   }
 
+  Geo_SnapNodes(GeoData_P);
+
 #else
   Message::Error("You need to compile GetDP with Gmsh support to open '%s'",
                  name);
@@ -995,6 +1017,8 @@ void Geo_ReadFile(struct GeoData * GeoData_P)
 
   }   /* while 1 ... */
 
+
+  Geo_SnapNodes(GeoData_P);
 }
 
 void Geo_ReadFileAdapt(struct GeoData * GeoData_P)
