@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -96,10 +96,10 @@ void  Geo_CreateEntitiesOfElement
    int * Geo_NbrElementsWithEntities2,
    int * Geo_NumCurrentEntity2, Tree_T * Geo_Entities2XEntities1) ;
 
-
-void  Geo_GenerateEdgesOfTree(List_T * InitialList, List_T * InitialSuppList,
-                              List_T * InitialSuppList2, int SuppListType2,
-			      List_T ** ExtendedList) ;
+void Geo_GenerateEdgesOfTree(List_T * InitialList, bool isInitialListEL,
+                             List_T * InitialSuppList, bool isInitialSuppListEL,
+                             List_T * InitialSuppList2, bool isInitialSuppList2EL,
+                             int SuppListType2, List_T ** ExtendedList);
 void  Geo_GenerateFacetsOfTree(List_T * InitialList, List_T * InitialSuppList,
                                List_T * InitialSuppList2,
 			       List_T ** ExtendedList) ;
