@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -21,7 +21,7 @@ extern int               Flag_XDATA ;
 double * Geo_GetNodes_uvw(int Type, int *nbn)
 {
   switch(Type){
-  case POINT       : *nbn = NbrNodes_Point ;       return(*Nodes_Point) ;
+  case POINT_ELEMENT : *nbn = NbrNodes_Point ;     return(*Nodes_Point) ;
 
   case LINE        : *nbn = NbrNodes_Line ;        return(*Nodes_Line) ;
   case TRIANGLE    : *nbn = NbrNodes_Triangle ;    return(*Nodes_Triangle) ;
@@ -51,6 +51,7 @@ void Geo_CreateEdgesOfElement(struct Geo_Element * Geo_Element)
   int  Nbr_Entities2, * D_Element ;
 
   D_Element = Geo_GetIM_Den(Geo_Element->Type, &Nbr_Entities2) ;
+  if(!Nbr_Entities2) return;
   Geo_CreateEntitiesOfElement(Nbr_Entities2, D_Element,
 			      Geo_Element->NbrNodes, Geo_Element->NumNodes,
 			      &Geo_Element->NbrEdges, &Geo_Element->NumEdges,
@@ -92,6 +93,7 @@ void Geo_CreateFacetsOfElement(struct Geo_Element * Geo_Element)
   int  Nbr_Entities2, * D_Element ;
 
   D_Element = Geo_GetIM_Dfe(Geo_Element->Type, &Nbr_Entities2) ;
+  if(!Nbr_Entities2) return;
   Geo_CreateEntitiesOfElement(Nbr_Entities2, D_Element,
 			      Geo_Element->NbrEdges, Geo_Element->NumEdges,
 			      &Geo_Element->NbrFacets, &Geo_Element->NumFacets,
@@ -108,7 +110,7 @@ int *Geo_GetIM_Den(int Type_Element, int * Nbe)
 {
 
   switch (Type_Element) {
-  case POINT :
+  case POINT_ELEMENT :
     *Nbe = NbrEdges_Point       ; return(NULL) ;
 
   case LINE   : case LINE_2 :
@@ -152,7 +154,7 @@ int *Geo_GetIM_Den(int Type_Element, int * Nbe)
 int *Geo_GetIM_Dfe(int Type_Element, int * Nbf)
 {
   switch (Type_Element) {
-  case POINT :
+  case POINT_ELEMENT :
     *Nbf = NbrFacets_Point       ; return(NULL) ;
 
   case LINE   : case LINE_2 :
@@ -196,7 +198,7 @@ int *Geo_GetIM_Dfe(int Type_Element, int * Nbf)
 int *Geo_GetIM_Dfn(int Type_Element, int * Nbf)
 {
   switch (Type_Element) {
-  case POINT :
+  case POINT_ELEMENT :
     *Nbf = NbrFacets_Point       ; return(NULL) ;
 
   case LINE   : case LINE_2 :
@@ -240,7 +242,7 @@ int *Geo_GetIM_Dfn(int Type_Element, int * Nbf)
 int * Geo_GetIM_Den_Xp(int Type_Element, int * Nbe, int * Nbn)
 {
   switch (Type_Element) {
-  case POINT :
+  case POINT_ELEMENT :
     *Nbe = NbrEdges_Point ; *Nbn = NbrNodes_Point ;
     return(NULL) ;
 
@@ -292,7 +294,7 @@ int * Geo_GetIM_Den_Xp(int Type_Element, int * Nbe, int * Nbn)
 int * Geo_GetIM_Dfe_Xp(int Type_Element, int * nbf, int * nbe)
 {
   switch (Type_Element) {
-  case POINT :
+  case POINT_ELEMENT :
     *nbf = NbrFacets_Point ; *nbe = NbrEdges_Point ;
     return(NULL) ;
 
