@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -90,74 +90,84 @@ static void Geo_GenerateTreeOnSlidingSurface(List_T *InitialList,
   List_Copy(Tree2List(EdgesInTree_T), ExtendedList);
 }
 
-static void Geo_GenerateEdgesOfTreeByDimension(int dim, List_T *InitialList,
+static void Geo_GenerateEdgesOfTreeByDimension(int dim, List_T *List,
+                                               bool isElementList, 
                                                List_T *ExtendedList,
                                                Tree_T *EntitiesInTree_T)
 {
-  int Nbr_Element, i_Element, Nbr_Entities2, i, Num_Entity1, Dim_Element;
+  int Nbr_Element, Num_Element, i_Element, Nbr_Entities2, i, Num_Entity1, Dim_Element;
   struct Geo_Element *Geo_Element;
   int i_Entity2, Num_Entity2, *D_Element, *Entity_P, Entity, Flag_Change;
   struct EntityInTree *EntitiesInTree_P[NBR_MAX_ENTITIES_IN_ELEMENT];
   struct EntityInTree EntityInTree_S;
 
-  Nbr_Element = Geo_GetNbrGeoElements();
+
+  Nbr_Element = isElementList ? List_Nbr(List) : Geo_GetNbrGeoElements();
+
   for(i_Element = 0; i_Element < Nbr_Element; i_Element++) {
-    Geo_Element = Geo_GetGeoElement(i_Element);
+    if( isElementList ){
+      List_Read(List,i_Element, &Num_Element);
+      Geo_Element = Geo_GetGeoElementOfNum(Num_Element);
+    }
+    else{
+      Geo_Element = Geo_GetGeoElement(i_Element);
+      if(!List_Search(List, &Geo_Element->Region, fcmp_int)) 
+        continue;
+    }
 
-    if(List_Search(InitialList, &Geo_Element->Region, fcmp_int)) {
-      Get_JacobianFunction(JACOBIAN_VOL, Geo_Element->Type, &Dim_Element);
-      if(Dim_Element == dim) {
-        if(Geo_Element->NbrEdges == 0) Geo_CreateEdgesOfElement(Geo_Element);
-        D_Element = Geo_GetIM_Den(Geo_Element->Type, &Nbr_Entities2);
+    Get_JacobianFunction(JACOBIAN_VOL, Geo_Element->Type, &Dim_Element);
+    if(dim < 0 || Dim_Element == dim) {
+      if(Geo_Element->NbrEdges == 0) Geo_CreateEdgesOfElement(Geo_Element);
+      D_Element = Geo_GetIM_Den(Geo_Element->Type, &Nbr_Entities2);
 
-        for(i = 0; i < Geo_Element->NbrNodes; i++) {
-          Num_Entity1 = abs(Geo_Element->NumNodes[i]);
-          EntitiesInTree_P[i] =
-            (struct EntityInTree *)Tree_PQuery(EntitiesInTree_T, &Num_Entity1);
-        }
+      for(i = 0; i < Geo_Element->NbrNodes; i++) {
+        Num_Entity1 = abs(Geo_Element->NumNodes[i]);
+        EntitiesInTree_P[i] =
+          (struct EntityInTree *)Tree_PQuery(EntitiesInTree_T, &Num_Entity1);
+      }
 
-        for(i_Entity2 = 0; i_Entity2 < Geo_Element->NbrEdges; i_Entity2++) {
-          Entity_P = D_Element + i_Entity2 * NBR_MAX_SUBENTITIES_IN_ELEMENT;
+      for(i_Entity2 = 0; i_Entity2 < Geo_Element->NbrEdges; i_Entity2++) {
+        Entity_P = D_Element + i_Entity2 * NBR_MAX_SUBENTITIES_IN_ELEMENT;
 
-          i = 0;
-          EntityInTree_S.Index = -1;
-          while((Entity = abs(Entity_P[i++])) && (EntityInTree_S.Index < 0))
-            if(EntitiesInTree_P[Entity - 1] != NULL)
-              EntityInTree_S.Index = EntitiesInTree_P[Entity - 1]->Index;
-          if(EntityInTree_S.Index < 0) EntityInTree_S.Index = Geo_Element->Num;
+        i = 0;
+        EntityInTree_S.Index = -1;
+        while((Entity = abs(Entity_P[i++])) && (EntityInTree_S.Index < 0))
+          if(EntitiesInTree_P[Entity - 1] != NULL)
+            EntityInTree_S.Index = EntitiesInTree_P[Entity - 1]->Index;
+        if(EntityInTree_S.Index < 0) EntityInTree_S.Index = Geo_Element->Num;
 
-          Flag_Change = 0;
+        Flag_Change = 0;
 
-          while((Entity = abs(*(Entity_P++)))) {
-            if(EntitiesInTree_P[--Entity] != NULL) {
-              if(EntitiesInTree_P[Entity]->Index != EntityInTree_S.Index) {
-                Tree_IndexToChange = EntitiesInTree_P[Entity]->Index;
-                Tree_NewIndex = EntityInTree_S.Index;
-                Tree_Action(EntitiesInTree_T, Geo_ChangeTreeIndex);
-                Flag_Change = 1;
-              }
-            }
-            else {
-              EntityInTree_S.Num = abs(Geo_Element->NumNodes[Entity]);
-              EntitiesInTree_P[Entity] = (struct EntityInTree *)Tree_Add(
-                EntitiesInTree_T, &EntityInTree_S);
+        while((Entity = abs(*(Entity_P++)))) {
+          if(EntitiesInTree_P[--Entity] != NULL) {
+            if(EntitiesInTree_P[Entity]->Index != EntityInTree_S.Index) {
+              Tree_IndexToChange = EntitiesInTree_P[Entity]->Index;
+              Tree_NewIndex = EntityInTree_S.Index;
+              Tree_Action(EntitiesInTree_T, Geo_ChangeTreeIndex);
               Flag_Change = 1;
             }
           }
-
-          if(Flag_Change) {
-            Num_Entity2 = abs(Geo_Element->NumEdges[i_Entity2]);
-            List_Add(ExtendedList, &Num_Entity2);
+          else {
+            EntityInTree_S.Num = abs(Geo_Element->NumNodes[Entity]);
+            EntitiesInTree_P[Entity] = 
+              (struct EntityInTree *)Tree_Add(EntitiesInTree_T, &EntityInTree_S);
+            Flag_Change = 1;
           }
-        } /* for i_Entity2 ... */
-      } /* if (Dim) */
-    } /* if Region ... */
+        }
+
+        if(Flag_Change) {
+          Num_Entity2 = abs(Geo_Element->NumEdges[i_Entity2]);
+          List_Add(ExtendedList, &Num_Entity2);
+        }
+      } /* for i_Entity2 ... */
+    } /* if (Dim) */
   } /* for i_Element ... */
 }
 
-void Geo_GenerateEdgesOfTree(List_T *InitialList, List_T *InitialSuppList,
-                             List_T *InitialSuppList2, int SuppListType2,
-                             List_T **ExtendedList)
+void Geo_GenerateEdgesOfTree(List_T * InitialList, bool isInitialListEL,
+                             List_T * InitialSuppList, bool isInitialSuppListEL,
+                             List_T * InitialSuppList2, bool isInitialSuppList2EL,
+                             int SuppListType2, List_T ** ExtendedList)
 {
   Tree_T *EntitiesInTree_T;
 
@@ -169,20 +179,21 @@ void Geo_GenerateEdgesOfTree(List_T *InitialList, List_T *InitialSuppList,
     Geo_GenerateTreeOnSlidingSurface(InitialSuppList2, *ExtendedList,
                                      EntitiesInTree_T, SuppListType2);
   if(InitialSuppList != NULL) { // SubRegion
-    Geo_GenerateEdgesOfTreeByDimension(1, InitialSuppList, *ExtendedList,
-                                       EntitiesInTree_T);
-    Geo_GenerateEdgesOfTreeByDimension(2, InitialSuppList, *ExtendedList,
-                                       EntitiesInTree_T);
+    Geo_GenerateEdgesOfTreeByDimension(1, InitialSuppList, isInitialSuppListEL,
+                                       *ExtendedList, EntitiesInTree_T);
+    Geo_GenerateEdgesOfTreeByDimension(2, InitialSuppList, isInitialSuppListEL,
+                                       *ExtendedList, EntitiesInTree_T);
   }
   if(InitialList != NULL) { // Region
-    Geo_GenerateEdgesOfTreeByDimension(3, InitialList, *ExtendedList,
-                                       EntitiesInTree_T);
+    Geo_GenerateEdgesOfTreeByDimension(-1, InitialList, isInitialListEL,
+                                       *ExtendedList, EntitiesInTree_T);
   }
 
   Tree_Delete(EntitiesInTree_T);
   List_Sort(*ExtendedList, fcmp_int);
 }
 
+
 /* ------------------------------------------------------------------------ */
 /*  G e o _ G e n e r a t e F a c e t s O f T r e e                         */
 /* ------------------------------------------------------------------------ */
