@@ -1,16 +1,16 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <getdp@onelab.info>.
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
-#ifndef _GET_FUNCTION_VALUE_H_
-#define _GET_FUNCTION_VALUE_H_
+#ifndef GET_FUNCTION_VALUE_H
+#define GET_FUNCTION_VALUE_H
 
 #include "ProData.h"
 
 int Get_ValueFromForm(int Form);
-struct IntegrationCase * Get_IntegrationCase (struct Element * Element, 
-					      List_T *IntegrationCase_L, 
+struct IntegrationCase * Get_IntegrationCase (struct Element * Element,
+					      List_T *IntegrationCase_L,
 					      int     CriterionIndex);
 void  Get_FunctionValue(int Nbr_Function,
 			void (*xFunctionBF[])(),
