@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -62,7 +62,7 @@ void  * Get_JacobianFunction(int Type_Jacobian, int Type_Element,
 
     switch (Type_Element) {
 
-    case POINT       :
+    case POINT_ELEMENT       :
       *Type_Dimension = DIM_0D; return((void *)JacobianVol0D);
 
     case LINE        : case LINE_2       : case LINE_3       : case LINE_4 :
@@ -74,9 +74,12 @@ void  * Get_JacobianFunction(int Type_Jacobian, int Type_Element,
       *Type_Dimension = DIM_2D; return((void *)JacobianVol2D);
 
     case TETRAHEDRON : case TETRAHEDRON_2 : case TETRAHEDRON_3 : case TETRAHEDRON_4 :
-    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_3  : case HEXAHEDRON_4  :
-    case PRISM       : case PRISM_2       : case PRISM_3       : case PRISM_4       :
-    case PYRAMID     : case PYRAMID_2     : case PYRAMID_3     : case PYRAMID_4     :
+    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_2_20N  :
+    case HEXAHEDRON_3: case HEXAHEDRON_4  :
+    case PRISM       : case PRISM_2       : case PRISM_2_15N   :
+    case PRISM_3     : case PRISM_4       :
+    case PYRAMID     : case PYRAMID_2     : case PYRAMID_2_13N :
+    case PYRAMID_3   : // case PYRAMID_4     :
       *Type_Dimension = DIM_3D; return((void *)JacobianVol3D);
 
     default :
@@ -94,9 +97,12 @@ void  * Get_JacobianFunction(int Type_Jacobian, int Type_Element,
       *Type_Dimension = DIM_2D; return((void *)JacobianVolSphShell2D);
 
     case TETRAHEDRON : case TETRAHEDRON_2 : case TETRAHEDRON_3 : case TETRAHEDRON_4 :
-    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_3  : case HEXAHEDRON_4  :
-    case PRISM       : case PRISM_2       : case PRISM_3       : case PRISM_4       :
-    case PYRAMID     : case PYRAMID_2     : case PYRAMID_3     : case PYRAMID_4     :
+    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_2_20N  :
+    case HEXAHEDRON_3: case HEXAHEDRON_4  :
+    case PRISM       : case PRISM_2       : case PRISM_2_15N   :
+    case PRISM_3     : case PRISM_4       :
+    case PYRAMID     : case PYRAMID_2     : case PYRAMID_2_13N :
+    case PYRAMID_3   : // case PYRAMID_4     :
       *Type_Dimension = DIM_3D; return((void *)JacobianVolSphShell3D);
 
     default :
@@ -114,9 +120,12 @@ void  * Get_JacobianFunction(int Type_Jacobian, int Type_Element,
       *Type_Dimension = DIM_2D; return((void *)JacobianVolSphShell2D);
 
     case TETRAHEDRON : case TETRAHEDRON_2 : case TETRAHEDRON_3 : case TETRAHEDRON_4 :
-    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_3  : case HEXAHEDRON_4  :
-    case PRISM       : case PRISM_2       : case PRISM_3       : case PRISM_4       :
-    case PYRAMID     : case PYRAMID_2     : case PYRAMID_3     : case PYRAMID_4     :
+    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_2_20N  :
+    case HEXAHEDRON_3: case HEXAHEDRON_4  :
+    case PRISM       : case PRISM_2       : case PRISM_2_15N   :
+    case PRISM_3     : case PRISM_4       :
+    case PYRAMID     : case PYRAMID_2     : case PYRAMID_2_13N :
+    case PYRAMID_3   : // case PYRAMID_4     :
       *Type_Dimension = DIM_3D; return((void *)JacobianVolCylShell3D);
 
     default :
@@ -134,9 +143,12 @@ void  * Get_JacobianFunction(int Type_Jacobian, int Type_Element,
       *Type_Dimension = DIM_2D; return((void *)JacobianVolRectShell2D);
 
     case TETRAHEDRON : case TETRAHEDRON_2 : case TETRAHEDRON_3 : case TETRAHEDRON_4 :
-    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_3  : case HEXAHEDRON_4  :
-    case PRISM       : case PRISM_2       : case PRISM_3       : case PRISM_4       :
-    case PYRAMID     : case PYRAMID_2     : case PYRAMID_3     : case PYRAMID_4     :
+    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_2_20N  :
+    case HEXAHEDRON_3: case HEXAHEDRON_4  :
+    case PRISM       : case PRISM_2       : case PRISM_2_15N   :
+    case PRISM_3     : case PRISM_4       :
+    case PYRAMID     : case PYRAMID_2     : case PYRAMID_2_13N :
+    case PYRAMID_3   : // case PYRAMID_4     :
       *Type_Dimension = DIM_3D; return((void *)JacobianVolRectShell3D);
 
     default :
@@ -149,9 +161,12 @@ void  * Get_JacobianFunction(int Type_Jacobian, int Type_Element,
     switch (Type_Element) {
 
     case TETRAHEDRON : case TETRAHEDRON_2 : case TETRAHEDRON_3 : case TETRAHEDRON_4 :
-    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_3  : case HEXAHEDRON_4  :
-    case PRISM       : case PRISM_2       : case PRISM_3       : case PRISM_4       :
-    case PYRAMID     : case PYRAMID_2     : case PYRAMID_3     : case PYRAMID_4     :
+    case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_2_20N  :
+    case HEXAHEDRON_3: case HEXAHEDRON_4  :
+    case PRISM       : case PRISM_2       : case PRISM_2_15N   :
+    case PRISM_3     : case PRISM_4       :
+    case PYRAMID     : case PYRAMID_2     : case PYRAMID_2_13N :
+    case PYRAMID_3   : // case PYRAMID_4     :
       *Type_Dimension = DIM_3D; return((void *)JacobianVolUniDirShell3D);
 
     default :
@@ -282,7 +297,7 @@ void  * Get_JacobianFunction(int Type_Jacobian, int Type_Element,
 
     switch (Type_Element) {
 
-    case POINT :
+    case POINT_ELEMENT :
       *Type_Dimension = DIM_1D; return((void *)JacobianVol0D);
 
     case LINE        : case LINE_2       : case LINE_3       : case LINE_4 :
@@ -333,7 +348,7 @@ void  * Get_JacobianFunction(int Type_Jacobian, int Type_Element,
 
     switch (Type_Element) {
 
-    case POINT :
+    case POINT_ELEMENT :
       *Type_Dimension = DIM_2D; return((void *)JacobianVol0D);
 
     case LINE        : case LINE_2       : case LINE_3       : case LINE_4 :
@@ -357,7 +372,7 @@ void  * Get_JacobianFunction(int Type_Jacobian, int Type_Element,
 void  * Get_JacobianFunctionAuto (int Type_Element, int Dimension)
 {
   switch(Type_Element){
-  case POINT :
+  case POINT_ELEMENT :
     return((void *)JacobianVol0D);
   case LINE        : case LINE_2       : case LINE_3       : case LINE_4 :
     switch(Dimension){
@@ -373,9 +388,12 @@ void  * Get_JacobianFunctionAuto (int Type_Element, int Dimension)
     default :  return((void *)JacobianVol2D);
     }
   case TETRAHEDRON : case TETRAHEDRON_2 : case TETRAHEDRON_3 : case TETRAHEDRON_4 :
-  case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_3  : case HEXAHEDRON_4  :
-  case PRISM       : case PRISM_2       : case PRISM_3       : case PRISM_4       :
-  case PYRAMID     : case PYRAMID_2     : case PYRAMID_3     : case PYRAMID_4     :
+  case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_2_20N  :
+  case HEXAHEDRON_3: case HEXAHEDRON_4  :
+  case PRISM       : case PRISM_2       : case PRISM_2_15N   :
+  case PRISM_3     : case PRISM_4       :
+  case PYRAMID     : case PYRAMID_2     : case PYRAMID_2_13N :
+  case PYRAMID_3   : // case PYRAMID_4     :
   default:
     return((void *)JacobianVol3D);
   }
@@ -390,7 +408,7 @@ void  * Get_IntegrationFunctionAuto (int Type_Element, int Order, int *NumPoints
   // TODO : compute correct number of points
 
   switch(Type_Element){
-  case POINT :
+  case POINT_ELEMENT :
     *NumPoints = 1;
     return ((void *)Gauss_Point);
   case LINE : case LINE_2 :
@@ -405,13 +423,13 @@ void  * Get_IntegrationFunctionAuto (int Type_Element, int Order, int *NumPoints
   case TETRAHEDRON : case TETRAHEDRON_2 :
     *NumPoints = 15;
     return ((void*)Gauss_Tetrahedron);
-  case HEXAHEDRON  : case HEXAHEDRON_2  :
+  case HEXAHEDRON  : case HEXAHEDRON_2  : case HEXAHEDRON_2_20N :
     *NumPoints = 34;
     return ((void*)Gauss_Hexahedron);
-  case PRISM       : case PRISM_2       :
+  case PRISM       : case PRISM_2       : case PRISM_2_15N   :
     *NumPoints = 21;
     return ((void*)Gauss_Prism);
-  case PYRAMID     : case PYRAMID_2     :
+  case PYRAMID     : case PYRAMID_2     : case PYRAMID_2_13N :
     *NumPoints = 8;
     return ((void*)Gauss_Pyramid);
   default:
