@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -30,6 +30,7 @@
 int     Flag_PRE = 0, Flag_CAL = 0, Flag_POS = 0, Flag_RESTART = 0;
 int     Flag_XDATA = 0, Flag_BIN = 0, Flag_SPLIT = 0, Flag_GMSH_VERSION = 1;
 int     Flag_NETWORK_CACHE = 0, Flag_CALLED_WITH_ONELAB_SERVER = 0;
+int     Flag_SLEPC = 0;
 double  Flag_ORDER = -1., Flag_MSH_SCALING = 1.;
 char   *Name_Generic = 0, *Name_Path = 0;
 char   *Name_Resolution = 0;
@@ -45,7 +46,7 @@ static void Info(int level, char *arg0)
   case 0 :
     fprintf(stderr,
 	    "GetDP, a General environment for the treatment of Discrete Problems\n"
-	    "Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege\n"
+	    "Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege\n"
 	    "Usage: %s [file] [options]\n"
 	    "Processing options:\n"
 	    "  -pre 'Resolution'         pre-processing\n"
@@ -306,6 +307,10 @@ static void Get_Options(int argc, char *argv[], int *sargc, char **sargv, char *
 	}
       }
 
+      else if (!strcmp(argv[i]+1, "slepc")) {
+        Flag_SLEPC = 1; i++;
+      }
+
       else if (!strcmp(argv[i]+1, "solve") ||
 	       !strcmp(argv[i]+1, "sol")) {
 	i++;
@@ -663,6 +668,7 @@ int MainKernel(int argc, char *argv[])
 #if defined(HAVE_GMSH)
   Message::Info("Initializing Gmsh");
   gmsh::initialize();
+  gmsh::option::setNumber("General.Terminal", 0);
   GmshMsg *msg = 0;
   if(!GmshGetMessageHandler() && !Flag_CALLED_WITH_ONELAB_SERVER){
     // do not set msg handler if one is provided (e.g. on Android/iOS)
