@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -186,7 +186,7 @@ void Cut_PostElement(struct PostElement * PE, struct Geo_Element * GE,
 
     switch(PE->Type){
 
-    case POINT :
+    case POINT_ELEMENT :
       Message::Error("Impossible to divide a Point recursively");
       break;
 
@@ -243,6 +243,50 @@ void Cut_PostElement(struct PostElement * PE, struct Geo_Element * GE,
       NbCut = 4 ;
       break;
 
+    case QUADRANGLE :
+    case QUADRANGLE_2 :
+    case QUADRANGLE_3 :
+    case QUADRANGLE_4 :
+      u01 = .5 * (PE->u[0] + PE->u[1]); u12 = .5 * (PE->u[1] + PE->u[2]);
+      v01 = .5 * (PE->v[0] + PE->v[1]);	v12 = .5 * (PE->v[1] + PE->v[2]);
+      w01 = .5 * (PE->w[0] + PE->w[1]);	w12 = .5 * (PE->w[1] + PE->w[2]);
+
+      u23 = .5 * (PE->u[2] + PE->u[3]); u03 = .5 * (PE->u[0] + PE->u[3]);
+      v23 = .5 * (PE->v[2] + PE->v[3]); v03 = .5 * (PE->v[0] + PE->v[3]);
+      w23 = .5 * (PE->w[2] + PE->w[3]); w03 = .5 * (PE->w[0] + PE->w[3]);
+
+      u02 = .5 * (PE->u[0] + PE->u[2]);
+      v02 = .5 * (PE->v[0] + PE->v[2]);
+      w02 = .5 * (PE->w[0] + PE->w[2]);
+
+      C[0] = Create_PostElement(Index, QUADRANGLE, 4, PE->Depth) ;
+      C[0]->u[0] = PE->u[0] ; C[0]->v[0] = PE->v[0] ; C[0]->w[0] = PE->w[0] ;
+      C[0]->u[1] = u01      ; C[0]->v[1] = v01      ; C[0]->w[1] = w01      ;
+      C[0]->u[2] = u02      ; C[0]->v[2] = v02      ; C[0]->w[2] = w02      ;
+      C[0]->u[3] = u03      ; C[0]->v[3] = v03      ; C[0]->w[3] = w03      ;
+
+      C[1] = Create_PostElement(Index, QUADRANGLE, 4, PE->Depth) ;
+      C[1]->u[0] = u01      ; C[1]->v[0] = v01      ; C[1]->w[0] = w01      ;
+      C[1]->u[1] = PE->u[1] ; C[1]->v[1] = PE->v[1] ; C[1]->w[1] = PE->w[1] ;
+      C[1]->u[2] = u12      ; C[1]->v[2] = v12      ; C[1]->w[2] = w12      ;
+      C[1]->u[3] = u02      ; C[1]->v[3] = v02      ; C[1]->w[3] = w02      ;
+
+      C[2] = Create_PostElement(Index, QUADRANGLE, 4, PE->Depth) ;
+      C[2]->u[0] = u02      ; C[2]->v[0] = v02      ; C[2]->w[0] = w02      ;
+      C[2]->u[1] = u12      ; C[2]->v[1] = v12      ; C[2]->w[1] = w12      ;
+      C[2]->u[2] = PE->u[2] ; C[2]->v[2] = PE->v[2] ; C[2]->w[2] = PE->w[2] ;
+      C[2]->u[3] = u23      ; C[2]->v[3] = v23      ; C[2]->w[3] = w23      ;
+
+      C[3] = Create_PostElement(Index, QUADRANGLE, 4, PE->Depth) ;
+      C[3]->u[0] = u03      ; C[3]->v[0] = v03      ; C[3]->w[0] = w03      ;
+      C[3]->u[1] = u02      ; C[3]->v[1] = v02      ; C[3]->w[1] = w02      ;
+      C[3]->u[2] = u23      ; C[3]->v[2] = v23      ; C[3]->w[2] = w23      ;
+      C[3]->u[3] = PE->u[3] ; C[3]->v[3] = PE->v[3] ; C[3]->w[3] = PE->w[3] ;
+
+      NbCut = 4 ;
+      break;
+
+
     case TETRAHEDRON :
     case TETRAHEDRON_2 :
     case TETRAHEDRON_3 :
@@ -400,7 +444,7 @@ void Fill_PostElement(struct Geo_Element * GE, List_T * PE_L,
     if(!error){
       double dummy;
       for(int i = 0; i < Gauss; i++){
-        PE = Create_PostElement(Index, POINT, 1, 0) ;
+        PE = Create_PostElement(Index, POINT_ELEMENT, 1, 0) ;
         f(Gauss, i, &PE->u[0], &PE->v[0], &PE->w[0], &dummy);
         POS_CUT_FILL ;
       }
@@ -409,9 +453,9 @@ void Fill_PostElement(struct Geo_Element * GE, List_T * PE_L,
   }
   else if(!Depth){
 
-    PE = Create_PostElement(Index, POINT, 1, 0) ;
+    PE = Create_PostElement(Index, POINT_ELEMENT, 1, 0) ;
     switch(GE->Type){
-    case POINT :
+    case POINT_ELEMENT :
       PE->u[0] = 0.   ; PE->v[0] = 0.   ; PE->w[0] = 0.   ; break ;
     case LINE :
     case LINE_2 :
@@ -436,18 +480,21 @@ void Fill_PostElement(struct Geo_Element * GE, List_T * PE_L,
       PE->u[0] = 0.25 ; PE->v[0] = 0.25 ; PE->w[0] = 0.25 ; break ;
     case HEXAHEDRON :
     case HEXAHEDRON_2 :
+    case HEXAHEDRON_2_20N :
     case HEXAHEDRON_3 :
     case HEXAHEDRON_4 :
       PE->u[0] = 0.   ; PE->v[0] = 0.   ; PE->w[0] = 0.   ; break ;
     case PRISM :
     case PRISM_2 :
+    case PRISM_2_15N :
     case PRISM_3 :
     case PRISM_4 :
       PE->u[0] = 1./3.; PE->v[0] = 1./3.; PE->w[0] = 0.   ; break ;
     case PYRAMID :
     case PYRAMID_2 :
+    case PYRAMID_2_13N :
     case PYRAMID_3 :
-    case PYRAMID_4 :
+    //case PYRAMID_4 :
       PE->u[0] = 0.   ; PE->v[0] = 0.   ; PE->w[0] = 1./3.; break ;
     }
     POS_CUT_FILL ;
@@ -461,8 +508,8 @@ void Fill_PostElement(struct Geo_Element * GE, List_T * PE_L,
 
       switch(GE->Type){
 
-      case POINT :
-        PE = Create_PostElement(Index, POINT, 1, 1) ; /* node 1 */
+      case POINT_ELEMENT :
+        PE = Create_PostElement(Index, POINT_ELEMENT, 1, 1) ; /* node 1 */
         PE->NumNodes[0] = GE->NumNodes[0] ;
         PE->u[0] = 0. ; PE->v[0] = 0. ; PE->w[0] = 0. ;
         POS_CUT_FILL ;
@@ -550,7 +597,8 @@ void Fill_PostElement(struct Geo_Element * GE, List_T * PE_L,
         POS_CUT_FILL;
         break ;
 
-      case HEXAHEDRON : case HEXAHEDRON_2 : case HEXAHEDRON_3 :case HEXAHEDRON_4 :
+      case HEXAHEDRON : case HEXAHEDRON_2 : case HEXAHEDRON_2_20N :
+      case HEXAHEDRON_3 :case HEXAHEDRON_4 :
         if(HighOrder && GE->Type != HEXAHEDRON)
           PE = Create_HighOrderPostElement(GE, Index);
         if(!PE){
@@ -638,7 +686,7 @@ void Fill_PostElement(struct Geo_Element * GE, List_T * PE_L,
         POS_CUT_FILL;
 	break ;
 
-      case PRISM : case PRISM_2 : case PRISM_3 : case PRISM_4 :
+      case PRISM : case PRISM_2 : case PRISM_2_15N : case PRISM_3 : case PRISM_4 :
         if(HighOrder && GE->Type != PRISM)
           PE = Create_HighOrderPostElement(GE, Index);
         if(!PE){
@@ -692,7 +740,8 @@ void Fill_PostElement(struct Geo_Element * GE, List_T * PE_L,
         POS_CUT_FILL;
 	break ;
 
-      case PYRAMID : case PYRAMID_2 : case PYRAMID_3 : case PYRAMID_4 :
+      case PYRAMID : case PYRAMID_2 : case PYRAMID_2_13N :
+      case PYRAMID_3 : // case PYRAMID_4 :
         if(HighOrder && GE->Type != PYRAMID)
           PE = Create_HighOrderPostElement(GE, Index);
         if(!PE){
