@@ -1,4 +1,4 @@
-// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/getdp/getdp/issues.
@@ -6,6 +6,7 @@
 #include <sstream>
 #include <map>
 #include <vector>
+#include <list>
 #include <string.h>
 #include <math.h>
 #include <set>
@@ -209,14 +210,14 @@ static void GmshParsed_PrintElement(double Time, int TimeStep, int NbTimeStep, i
 
     if(TimeStep == 0){
       switch(Type){
-      case POINT       : fprintf(PostStream, "SP("); break;
-      case LINE        : fprintf(PostStream, "SL("); break;
-      case TRIANGLE    : fprintf(PostStream, "ST("); break;
-      case QUADRANGLE  : fprintf(PostStream, "SQ("); break;
-      case TETRAHEDRON : fprintf(PostStream, "SS("); break;
-      case HEXAHEDRON  : fprintf(PostStream, "SH("); break;
-      case PRISM       : fprintf(PostStream, "SI("); break;
-      case PYRAMID     : fprintf(PostStream, "SY("); break;
+      case POINT_ELEMENT : fprintf(PostStream, "SP("); break;
+      case LINE          : fprintf(PostStream, "SL("); break;
+      case TRIANGLE      : fprintf(PostStream, "ST("); break;
+      case QUADRANGLE    : fprintf(PostStream, "SQ("); break;
+      case TETRAHEDRON   : fprintf(PostStream, "SS("); break;
+      case HEXAHEDRON    : fprintf(PostStream, "SH("); break;
+      case PRISM         : fprintf(PostStream, "SI("); break;
+      case PYRAMID       : fprintf(PostStream, "SY("); break;
       }
       for(i = 0 ; i < NbrNodes ; i++){
 	if(i) fprintf(PostStream, ",");
@@ -254,14 +255,14 @@ static void GmshParsed_PrintElement(double Time, int TimeStep, int NbTimeStep, i
 
     if(TimeStep == 0){
       switch(Type){
-      case POINT       : fprintf(PostStream, "VP("); break;
-      case LINE        : fprintf(PostStream, "VL("); break;
-      case TRIANGLE    : fprintf(PostStream, "VT("); break;
-      case QUADRANGLE  : fprintf(PostStream, "VQ("); break;
-      case TETRAHEDRON : fprintf(PostStream, "VS("); break;
-      case HEXAHEDRON  : fprintf(PostStream, "VH("); break;
-      case PRISM       : fprintf(PostStream, "VI("); break;
-      case PYRAMID     : fprintf(PostStream, "VY("); break;
+      case POINT_ELEMENT : fprintf(PostStream, "VP("); break;
+      case LINE          : fprintf(PostStream, "VL("); break;
+      case TRIANGLE      : fprintf(PostStream, "VT("); break;
+      case QUADRANGLE    : fprintf(PostStream, "VQ("); break;
+      case TETRAHEDRON   : fprintf(PostStream, "VS("); break;
+      case HEXAHEDRON    : fprintf(PostStream, "VH("); break;
+      case PRISM         : fprintf(PostStream, "VI("); break;
+      case PYRAMID       : fprintf(PostStream, "VY("); break;
       }
       for(i = 0 ; i < NbrNodes ; i++){
 	if(i) fprintf(PostStream, ",");
@@ -307,14 +308,14 @@ static void GmshParsed_PrintElement(double Time, int TimeStep, int NbTimeStep, i
 
     if(TimeStep == 0){
       switch(Type){
-      case POINT       : fprintf(PostStream, "TP("); break;
-      case LINE        : fprintf(PostStream, "TL("); break;
-      case TRIANGLE    : fprintf(PostStream, "TT("); break;
-      case QUADRANGLE  : fprintf(PostStream, "TQ("); break;
-      case TETRAHEDRON : fprintf(PostStream, "TS("); break;
-      case HEXAHEDRON  : fprintf(PostStream, "TH("); break;
-      case PRISM       : fprintf(PostStream, "TI("); break;
-      case PYRAMID     : fprintf(PostStream, "TY("); break;
+      case POINT_ELEMENT : fprintf(PostStream, "TP("); break;
+      case LINE          : fprintf(PostStream, "TL("); break;
+      case TRIANGLE      : fprintf(PostStream, "TT("); break;
+      case QUADRANGLE    : fprintf(PostStream, "TQ("); break;
+      case TETRAHEDRON   : fprintf(PostStream, "TS("); break;
+      case HEXAHEDRON    : fprintf(PostStream, "TH("); break;
+      case PRISM         : fprintf(PostStream, "TI("); break;
+      case PYRAMID       : fprintf(PostStream, "TY("); break;
       }
       for(i = 0 ; i < NbrNodes ; i++){
 	if(i) fprintf(PostStream, ",");
@@ -400,14 +401,14 @@ static void Gmsh_PrintElement(double Time, int TimeStep, int NbTimeStep, int NbH
 
     if(TimeStep == 0){
       switch(Type){
-      case POINT       : Current_L = &SP ; NbSP++ ; break ;
-      case LINE        : Current_L = &SL ; NbSL++ ; break ;
-      case TRIANGLE    : Current_L = &ST ; NbST++ ; break ;
-      case QUADRANGLE  : Current_L = &SQ ; NbSQ++ ; break ;
-      case TETRAHEDRON : Current_L = &SS ; NbSS++ ; break ;
-      case HEXAHEDRON  : Current_L = &SH ; NbSH++ ; break ;
-      case PRISM       : Current_L = &SI ; NbSI++ ; break ;
-      case PYRAMID     : Current_L = &SY ; NbSY++ ; break ;
+      case POINT_ELEMENT  : Current_L = &SP ; NbSP++ ; break ;
+      case LINE           : Current_L = &SL ; NbSL++ ; break ;
+      case TRIANGLE       : Current_L = &ST ; NbST++ ; break ;
+      case QUADRANGLE     : Current_L = &SQ ; NbSQ++ ; break ;
+      case TETRAHEDRON    : Current_L = &SS ; NbSS++ ; break ;
+      case HEXAHEDRON     : Current_L = &SH ; NbSH++ ; break ;
+      case PRISM          : Current_L = &SI ; NbSI++ ; break ;
+      case PYRAMID        : Current_L = &SY ; NbSY++ ; break ;
 
       case LINE_2         : Current_L = &SL ; NbSL++ ; break ;
       case TRIANGLE_2     : Current_L = &ST ; NbST++ ; break ;
@@ -415,8 +416,11 @@ static void Gmsh_PrintElement(double Time, int TimeStep, int NbTimeStep, int NbH
       case QUADRANGLE_2_8N: Current_L = &SQ ; NbSQ++ ; break ;
       case TETRAHEDRON_2  : Current_L = &SS ; NbSS++ ; break ;
       case HEXAHEDRON_2   : Current_L = &SH ; NbSH++ ; break ;
+      case HEXAHEDRON_2_20N: Current_L = &SH ; NbSH++ ; break ;
       case PRISM_2        : Current_L = &SI ; NbSI++ ; break ;
+      case PRISM_2_15N    : Current_L = &SI ; NbSI++ ; break ;
       case PYRAMID_2      : Current_L = &SY ; NbSY++ ; break ;
+      case PYRAMID_2_13N  : Current_L = &SY ; NbSY++ ; break ;
 
       case LINE_3         : Current_L = &SL ; NbSL++ ; break ;
       case TRIANGLE_3     : Current_L = &ST ; NbST++ ; break ;
@@ -432,7 +436,7 @@ static void Gmsh_PrintElement(double Time, int TimeStep, int NbTimeStep, int NbH
       case TETRAHEDRON_4  : Current_L = &SS ; NbSS++ ; break ;
       case HEXAHEDRON_4   : Current_L = &SH ; NbSH++ ; break ;
       case PRISM_4        : Current_L = &SI ; NbSI++ ; break ;
-      case PYRAMID_4      : Current_L = &SY ; NbSY++ ; break ;
+      //case PYRAMID_4      : Current_L = &SY ; NbSY++ ; break ;
       }
       if(Flag_GMSH_VERSION != 2){
         for(i = 0 ; i < NbrNodes ; i++) Current_L->push_back(x[i]);
@@ -464,15 +468,15 @@ static void Gmsh_PrintElement(double Time, int TimeStep, int NbTimeStep, int NbH
 
     if(TimeStep == 0){
       switch(Type){
-      case POINT       : Current_L = &VP ; NbVP++ ; break ;
+      case POINT_ELEMENT  : Current_L = &VP ; NbVP++ ; break ;
 
-      case LINE        : Current_L = &VL ; NbVL++ ; break ;
-      case TRIANGLE    : Current_L = &VT ; NbVT++ ; break ;
-      case QUADRANGLE  : Current_L = &VQ ; NbVQ++ ; break ;
-      case TETRAHEDRON : Current_L = &VS ; NbVS++ ; break ;
-      case HEXAHEDRON  : Current_L = &VH ; NbVH++ ; break ;
-      case PRISM       : Current_L = &VI ; NbVI++ ; break ;
-      case PYRAMID     : Current_L = &VY ; NbVY++ ; break ;
+      case LINE           : Current_L = &VL ; NbVL++ ; break ;
+      case TRIANGLE       : Current_L = &VT ; NbVT++ ; break ;
+      case QUADRANGLE     : Current_L = &VQ ; NbVQ++ ; break ;
+      case TETRAHEDRON    : Current_L = &VS ; NbVS++ ; break ;
+      case HEXAHEDRON     : Current_L = &VH ; NbVH++ ; break ;
+      case PRISM          : Current_L = &VI ; NbVI++ ; break ;
+      case PYRAMID        : Current_L = &VY ; NbVY++ ; break ;
 
       case LINE_2         : Current_L = &VL ; NbVL++ ; break ;
       case TRIANGLE_2     : Current_L = &VT ; NbVT++ ; break ;
@@ -480,8 +484,11 @@ static void Gmsh_PrintElement(double Time, int TimeStep, int NbTimeStep, int NbH
       case QUADRANGLE_2_8N: Current_L = &VQ ; NbVQ++ ; break ;
       case TETRAHEDRON_2  : Current_L = &VS ; NbVS++ ; break ;
       case HEXAHEDRON_2   : Current_L = &VH ; NbVH++ ; break ;
+      case HEXAHEDRON_2_20N: Current_L = &VH ; NbVH++ ; break ;
       case PRISM_2        : Current_L = &VI ; NbVI++ ; break ;
+      case PRISM_2_15N    : Current_L = &VI ; NbVI++ ; break ;
       case PYRAMID_2      : Current_L = &VY ; NbVY++ ; break ;
+      case PYRAMID_2_13N  : Current_L = &VY ; NbVY++ ; break ;
 
       case LINE_3         : Current_L = &VL ; NbVL++ ; break ;
       case TRIANGLE_3     : Current_L = &VT ; NbVT++ ; break ;
@@ -497,7 +504,7 @@ static void Gmsh_PrintElement(double Time, int TimeStep, int NbTimeStep, int NbH
       case TETRAHEDRON_4  : Current_L = &VS ; NbVS++ ; break ;
       case HEXAHEDRON_4   : Current_L = &VH ; NbVH++ ; break ;
       case PRISM_4        : Current_L = &VI ; NbVI++ ; break ;
-      case PYRAMID_4      : Current_L = &VY ; NbVY++ ; break ;
+      //case PYRAMID_4      : Current_L = &VY ; NbVY++ ; break ;
       }
       if(Flag_GMSH_VERSION != 2){
         for(i = 0 ; i < NbrNodes ; i++) Current_L->push_back(x[i]);
@@ -533,15 +540,15 @@ static void Gmsh_PrintElement(double Time, int TimeStep, int NbTimeStep, int NbH
 
     if(TimeStep == 0){
       switch(Type){
-      case POINT       : Current_L = &TP ; NbTP++ ; break ;
+      case POINT_ELEMENT  : Current_L = &TP ; NbTP++ ; break ;
 
-      case LINE        : Current_L = &TL ; NbTL++ ; break ;
-      case TRIANGLE    : Current_L = &TT ; NbTT++ ; break ;
-      case QUADRANGLE  : Current_L = &TQ ; NbTQ++ ; break ;
-      case TETRAHEDRON : Current_L = &TS1 ; NbTS++ ; break ;
-      case HEXAHEDRON  : Current_L = &TH ; NbTH++ ; break ;
-      case PRISM       : Current_L = &TI ; NbTI++ ; break ;
-      case PYRAMID     : Current_L = &TY ; NbTY++ ; break ;
+      case LINE           : Current_L = &TL ; NbTL++ ; break ;
+      case TRIANGLE       : Current_L = &TT ; NbTT++ ; break ;
+      case QUADRANGLE     : Current_L = &TQ ; NbTQ++ ; break ;
+      case TETRAHEDRON    : Current_L = &TS1 ; NbTS++ ; break ;
+      case HEXAHEDRON     : Current_L = &TH ; NbTH++ ; break ;
+      case PRISM          : Current_L = &TI ; NbTI++ ; break ;
+      case PYRAMID        : Current_L = &TY ; NbTY++ ; break ;
 
       case LINE_2         : Current_L = &TL ; NbTL++ ; break ;
       case TRIANGLE_2     : Current_L = &TT ; NbTT++ ; break ;
@@ -549,8 +556,11 @@ static void Gmsh_PrintElement(double Time, int TimeStep, int NbTimeStep, int NbH
       case QUADRANGLE_2_8N: Current_L = &TQ ; NbTQ++ ; break ;
       case TETRAHEDRON_2  : Current_L = &TS1 ; NbTS++ ; break ;
       case HEXAHEDRON_2   : Current_L = &TH ; NbTH++ ; break ;
+      case HEXAHEDRON_2_20N: Current_L = &TH ; NbTH++ ; break ;
       case PRISM_2        : Current_L = &TI ; NbTI++ ; break ;
+      case PRISM_2_15N    : Current_L = &TI ; NbTI++ ; break ;
       case PYRAMID_2      : Current_L = &TY ; NbTY++ ; break ;
+      case PYRAMID_2_13N  : Current_L = &TY ; NbTY++ ; break ;
 
       case LINE_3         : Current_L = &TL ; NbTL++ ; break ;
       case TRIANGLE_3     : Current_L = &TT ; NbTT++ ; break ;
@@ -566,7 +576,7 @@ static void Gmsh_PrintElement(double Time, int TimeStep, int NbTimeStep, int NbH
       case TETRAHEDRON_4  : Current_L = &TS1 ; NbTS++ ; break ;
       case HEXAHEDRON_4   : Current_L = &TH ; NbTH++ ; break ;
       case PRISM_4        : Current_L = &TI ; NbTI++ ; break ;
-      case PYRAMID_4      : Current_L = &TY ; NbTY++ ; break ;
+      //case PYRAMID_4      : Current_L = &TY ; NbTY++ ; break ;
       }
       if(Flag_GMSH_VERSION != 2){
         for(i = 0 ; i < NbrNodes ; i++) Current_L->push_back(x[i]);
@@ -758,6 +768,10 @@ static void Gnuplot_PrintElement(int Format, double Time, int TimeStep, int NbrT
 /*  Tabular format                                                          */
 /* ------------------------------------------------------------------------ */
 
+// global static list for tables output
+static int TableList_StartNew = 0;
+static std::list<double> TableList;
+
 static void Tabular_PrintElement(struct PostSubOperation *PSO_P,
                                  int Format, double Time, int TimeStep, int NbrTimeSteps,
                                  int NbrHarmonics, int HarmonicToTime,
@@ -770,6 +784,11 @@ static void Tabular_PrintElement(struct PostSubOperation *PSO_P,
   double      TimeMH ;
   struct Value  TmpValue ;
 
+  if(TableList_StartNew){
+    TableList_StartNew = 0 ;
+    TableList.clear();
+  }
+
   if(!PostStream) return;
 
   if(TimeStep == 0){
@@ -785,16 +804,31 @@ static void Tabular_PrintElement(struct PostSubOperation *PSO_P,
   if(Format == FORMAT_SPACE_TABLE || Format == FORMAT_SIMPLE_SPACE_TABLE
      || Format == FORMAT_VALUE_ONLY){
     if(TimeStep == 0){
-      if(Format != FORMAT_SIMPLE_SPACE_TABLE && Format != FORMAT_VALUE_ONLY)
-        fprintf(PostStream, "%d %d  ", GetDP2Gmsh(ElementType), NumElement);
-      if(Format != FORMAT_VALUE_ONLY)
-        for(i=0 ; i<NbrNodes ; i++)
-          fprintf(PostStream, "%.16g %.16g %.16g  ", x[i], y[i], z[i]);
       if(Format != FORMAT_SIMPLE_SPACE_TABLE && Format != FORMAT_VALUE_ONLY){
-        if(Dummy)
+        fprintf(PostStream, "%d %d  ", GetDP2Gmsh(ElementType), NumElement);
+        TableList.push_back(GetDP2Gmsh(ElementType));
+        TableList.push_back(NumElement);
+      }
+      if(Format != FORMAT_VALUE_ONLY)
+        for(i=0 ; i<NbrNodes ; i++){
+          fprintf(PostStream, "%.16g %.16g %.16g  ", x[i], y[i], z[i]);
+          TableList.push_back(x[i]);
+          TableList.push_back(y[i]);
+          TableList.push_back(z[i]);
+        }
+      if(Format != FORMAT_SIMPLE_SPACE_TABLE && Format != FORMAT_VALUE_ONLY){
+        if(Dummy){
           fprintf(PostStream, "%.16g %.16g %.16g  ", Dummy[0], Dummy[1],  Dummy[2]);
-        else
+          TableList.push_back(Dummy[0]);
+          TableList.push_back(Dummy[1]);
+          TableList.push_back(Dummy[2]);
+        }
+        else{
           fprintf(PostStream, "0 0 0  ");
+          TableList.push_back(0);
+          TableList.push_back(0);
+          TableList.push_back(0);
+        }
       }
     }
   }
@@ -802,22 +836,31 @@ static void Tabular_PrintElement(struct PostSubOperation *PSO_P,
   if (HarmonicToTime == 1) {
     if(Format == FORMAT_TIME_TABLE){
       fprintf(PostStream, "%d %.16g ", TimeStep, Time);
-      for(i=0 ; i<NbrNodes ; i++)
-	fprintf(PostStream, " %.16g %.16g %.16g ", x[i], y[i], z[i]);
+      TableList.push_back(TimeStep);
+      TableList.push_back(Time);
+      for(i=0 ; i<NbrNodes ; i++){
+        fprintf(PostStream, " %.16g %.16g %.16g ", x[i], y[i], z[i]);
+        TableList.push_back(x[i]);
+        TableList.push_back(y[i]);
+        TableList.push_back(z[i]);
+      }
     }
     for(k = 0 ; k < NbrHarmonics ; k++) {
       for(i = 0 ; i < NbrNodes ; i++){
-	for(j = 0 ; j < Size ; j++){
-          if (Format != FORMAT_VALUE_ONLY)
+        for(j = 0 ; j < Size ; j++){
+          if (Format != FORMAT_VALUE_ONLY){
             fprintf(PostStream, " %.16g", Value[i].Val[MAX_DIM*k+j]);
+            TableList.push_back(Value[i].Val[MAX_DIM*k+j]);
+          }
           else{
             fprintf(PostStream, " %s_%d_%d = %.16g",
                     PSO_P->ValueName, j, PSO_P->ValueIndex, Value[i].Val[MAX_DIM*k+j]);
+            TableList.push_back(Value[i].Val[MAX_DIM*k+j]);
             if (j<Size-1)
               fprintf(PostStream, "\n");
           }
-	}
-	fprintf(PostStream, " ");
+        }
+        fprintf(PostStream, " ");
       }
       fprintf(PostStream, " ");
     }
@@ -825,18 +868,26 @@ static void Tabular_PrintElement(struct PostSubOperation *PSO_P,
   else {
     for(k = 0 ; k < HarmonicToTime ; k++){
       for(i = 0 ; i < NbrNodes ; i++){
-	F_MHToTime0(k+i, &Value[i], &TmpValue, k, HarmonicToTime, &TimeMH) ;
-	if (!i && Format == FORMAT_TIME_TABLE) {
-	  fprintf(PostStream, "%d %.16g ", TimeStep, TimeMH);
-	  for(i=0 ; i<NbrNodes ; i++)
-	    fprintf(PostStream, " %.16g %.16g %.16g ", x[i], y[i], z[i]);
-	}
-	for(j = 0 ; j < Size ; j++)
-	  fprintf(PostStream, " %.16g", TmpValue.Val[j]) ;
-	fprintf(PostStream, " ");
+        F_MHToTime0(k+i, &Value[i], &TmpValue, k, HarmonicToTime, &TimeMH) ;
+        if (!i && Format == FORMAT_TIME_TABLE) {
+          fprintf(PostStream, "%d %.16g ", TimeStep, TimeMH);
+          TableList.push_back(TimeStep);
+          TableList.push_back(TimeMH);
+          for(i=0 ; i<NbrNodes ; i++){
+            fprintf(PostStream, " %.16g %.16g %.16g ", x[i], y[i], z[i]);
+            TableList.push_back(x[i]);
+            TableList.push_back(y[i]);
+            TableList.push_back(z[i]);
+          }
+        }
+        for(j = 0 ; j < Size ; j++){
+          fprintf(PostStream, " %.16g", TmpValue.Val[j]) ;
+          TableList.push_back(TmpValue.Val[j]);
+        }
+        fprintf(PostStream, " ");
       }
       if(Format == FORMAT_TIME_TABLE)
-	fprintf(PostStream, "\n");
+        fprintf(PostStream, "\n");
     }
   }
 
@@ -998,12 +1049,14 @@ static void StorePostOpResult(int NbrHarmonics, struct Value *Value)
 #define NX ;
 #endif
 
-void Unv_PrintHeader(FILE *PostStream, char *name, int SubType, double Time, int TimeStep) NX
-void Unv_PrintFooter(FILE *PostStream) NX
-void Unv_PrintElement(FILE *PostStream, int Num_Element, int NbrNodes, struct Value *Value, int NbrHarmonics) NX
-void Unv_PrintRegion(FILE *PostStream, int Flag_Comma, int numRegion, int NbrHarmonics,
-                     int Size, struct Value *Value) NX
+double NXUnv_UnitFactor = 1;
+int    NXUnv_DatasetLocation = 3; //1: Data at nodes, 2: Data on elements, 3: Data at nodes on elements
 
+void Unv_PrintHeader(FILE *PostStream, char *name, double Time, int TimeStep, double& NXUnv_UnitFactor, int& NXUnv_DatasetLocation) NX
+void Unv_PrintFooter(FILE *PostStream) NX
+void Unv_PrintElement(FILE *PostStream, int Num_Element, int NbrNodes, struct Value *Value, int NbrHarmonics, int& NXUnv_DatasetLocation, double& NXUnv_UnitFactor) NX
+void Unv_PrintNodeTable(FILE *PostStream, std::map<int, std::vector<double>> &NodeTable, double& NXUnv_UnitFactor) NX
+void Unv_PrintRegion(FILE *PostStream, int Flag_Comma, int numRegion, int NbrHarmonics, int Size, struct Value *Value, double& NXUnv_UnitFactor) NX
 #undef NX
 
 /* ------------------------------------------------------------------------ */
@@ -1115,7 +1168,6 @@ void  Format_PostHeader(struct PostSubOperation *PSO_P, int NbTimeStep,
 			int Order, char *Name1, char *Name2)
 {
   int Format = PSO_P->Format;
-  int SubType = PSO_P->SubType;
   double Time = Current.Time;
   int TimeStep = Current.TimeStep;
   int Contour = PSO_P->Iso;
@@ -1166,7 +1218,10 @@ void  Format_PostHeader(struct PostSubOperation *PSO_P, int NbTimeStep,
     }
     break ;
   case FORMAT_NXUNV :
-    if(PostStream) Unv_PrintHeader(PostStream, name, SubType, Time, TimeStep);
+    if(PostStream){
+		  NodeTable_StartNew = 1 ;
+		  Unv_PrintHeader(PostStream, name, Time, TimeStep, NXUnv_UnitFactor, NXUnv_DatasetLocation);
+	  }
     break ;
   case FORMAT_GNUPLOT :
     if(PostStream){
@@ -1180,6 +1235,12 @@ void  Format_PostHeader(struct PostSubOperation *PSO_P, int NbTimeStep,
   case FORMAT_ELEMENT_TABLE :
     ElementTable_StartNew = 1 ;
     break ;
+  case FORMAT_SPACE_TABLE :
+  case FORMAT_TIME_TABLE :
+  case FORMAT_SIMPLE_SPACE_TABLE :
+  case FORMAT_VALUE_ONLY :
+    TableList_StartNew = 1 ;
+    break ;
   case FORMAT_ADAPT :
     if(PostStream) fprintf(PostStream, "$Adapt /* %s */\n", name) ;
     break ;
@@ -1190,7 +1251,8 @@ void  Format_PostHeader(struct PostSubOperation *PSO_P, int NbTimeStep,
 /*  F o r m a t _ P o s t F o o t e r                                       */
 /* ------------------------------------------------------------------------ */
 
-void Format_PostFooter(struct PostSubOperation *PSO_P, int Store)
+void Format_PostFooter(struct PostSubOperation *PSO_P, int Store,
+                       bool SendToServer)
 {
   List_T    *Iso_L[NBR_MAX_ISO], *Solutions_L;
   double    IsoMin = 1.e200, IsoMax = -1.e200, IsoVal = 0.0, freq, valr, vali ;
@@ -1426,7 +1488,11 @@ void Format_PostFooter(struct PostSubOperation *PSO_P, int Store)
     if(PostStream) fprintf(PostStream, "$EndAdapt\n");
     break ;
   case FORMAT_NXUNV :
-    if(PostStream) Unv_PrintFooter(PostStream);
+    if(PostStream){
+		  if(NXUnv_DatasetLocation == 1) //Data at nodes
+			  Unv_PrintNodeTable(PostStream, NodeTable, NXUnv_UnitFactor);
+		  Unv_PrintFooter(PostStream);
+	  }
     break ;
   case FORMAT_NODE_TABLE :
     if(PostStream && NodeTable.size()){
@@ -1450,7 +1516,7 @@ void Format_PostFooter(struct PostSubOperation *PSO_P, int Store)
       }
       GetDPNumbers[CurrentName] = exp;
       GetDPNumbersMap[CurrentName] = NodeTable;
-      if(PSO_P->SendToServer && strcmp(PSO_P->SendToServer, "No"))
+      if(SendToServer && PSO_P->SendToServer && strcmp(PSO_P->SendToServer, "No"))
         Message::AddOnelabNumberChoice(PSO_P->SendToServer, exp, PSO_P->Color,
                                        PSO_P->Units, PSO_P->Label, PSO_P->Visible,
                                        PSO_P->Closed);
@@ -1478,12 +1544,27 @@ void Format_PostFooter(struct PostSubOperation *PSO_P, int Store)
       }
       GetDPNumbers[CurrentName] = exp;
       GetDPNumbersMap[CurrentName] = ElementTable;
-      if(PSO_P->SendToServer && strcmp(PSO_P->SendToServer, "No"))
+      if(SendToServer && PSO_P->SendToServer && strcmp(PSO_P->SendToServer, "No"))
         Message::AddOnelabNumberChoice(PSO_P->SendToServer, exp, PSO_P->Color,
                                        PSO_P->Units, PSO_P->Label, PSO_P->Visible,
                                        PSO_P->Closed);
     }
     break;
+  case FORMAT_SPACE_TABLE :
+  case FORMAT_TIME_TABLE :
+  case FORMAT_SIMPLE_SPACE_TABLE :
+  case FORMAT_VALUE_ONLY :
+    {
+      if(TableList.size()) {
+        std::vector<double> v(TableList.begin(), TableList.end());
+        GetDPNumbers[CurrentName] = v;
+        if(SendToServer && PSO_P->SendToServer && strcmp(PSO_P->SendToServer, "No"))
+          Message::AddOnelabNumberChoice(PSO_P->SendToServer, v, PSO_P->Color,
+                                         PSO_P->Units, PSO_P->Label, PSO_P->Visible,
+                                         PSO_P->Closed);
+      }
+    }
+    break;
   case FORMAT_LOOP_ERROR :
     Solutions_L = ((struct PostOpSolutions*)
       List_Pointer(Current.PostOpData_L, Current.PostOpDataIndex))->Solutions_L;
@@ -1622,7 +1703,12 @@ void  Format_PostElement(struct PostSubOperation *PSO_P, int Contour, int Store,
                             PE->Value) ;
     break ;
   case FORMAT_NXUNV :
-    if(PostStream) Unv_PrintElement(PostStream, Num_Element, PE->NbrNodes, PE->Value, NbrHarmonics) ;
+    if(PostStream){
+		  if(NXUnv_DatasetLocation == 1) //Data at nodes
+			  NodeTable_PrintElement(TimeStep, NbTimeStep, NbrHarmonics, PE);
+		  else if(NXUnv_DatasetLocation == 2 || NXUnv_DatasetLocation == 3) //Data at elements or nodes on elements
+			  Unv_PrintElement(PostStream, Num_Element, PE->NbrNodes, PE->Value, NbrHarmonics, NXUnv_DatasetLocation, NXUnv_UnitFactor) ;
+	  }
     break ;
   case FORMAT_GMSH :
     if(PSO_P->StoreInField >= 0 || PSO_P->StoreInMeshBasedField >= 0){
@@ -1694,7 +1780,7 @@ void  Format_PostElement(struct PostSubOperation *PSO_P, int Contour, int Store,
 
 void Format_PostValue(struct PostQuantity  *PQ_P,
                       struct PostSubOperation *PSO_P,
-                      int Format, int Flag_Comma, int Group_FunctionType,
+                      int Format, char *Comma, int Group_FunctionType,
 		      int iTime, double Time, int NbrTimeStep,
                       int iRegion, int numRegion, int NbrRegion,
 		      int NbrHarmonics, int HarmonicToTime, int FourierTransform,
@@ -1724,18 +1810,20 @@ void Format_PostValue(struct PostQuantity  *PQ_P,
 
   if (Format == FORMAT_REGION_TABLE) {
     if(iRegion == 0){
-      if(PostStream == stdout || PostStream == stderr)
-        Message::Direct("%d", NbrRegion);
-      else if(PostStream)
-        fprintf(PostStream, "%d\n", NbrRegion) ;
+      if(PostStream == stdout || PostStream == stderr) {
+        Message::Direct("%d%s", NbrRegion, Comma ? Comma : "");
+      }
+      else if(PostStream) {
+        fprintf(PostStream, "%d%s\n", NbrRegion, Comma ? Comma : "") ;
+      }
     }
     std::ostringstream sstream;
     sstream.precision(16);
     sstream << numRegion;
     for (k = 0 ; k < NbrHarmonics ; k++) {
       for(j = 0 ; j < Size ; j++) {
-	if (Flag_Comma) sstream << ",";
-	sstream << " " << Value->Val[MAX_DIM*k+j] ;
+        sstream << " " << Value->Val[MAX_DIM*k+j] ;
+	if (Comma) sstream << Comma;
       }
     }
     if(PostStream == stdout || PostStream == stderr)
@@ -1775,12 +1863,13 @@ void Format_PostValue(struct PostQuantity  *PQ_P,
                        " by Regions. Zero coordinates are considered.") ;
     }
     GmshParsed_PrintElement(Time, 0, 1, NbrHarmonics, HarmonicToTime,
-                            POINT, 1, &x, &y, &z,
+                            POINT_ELEMENT, 1, &x, &y, &z,
                             Value) ;
   }
   else if (Format == FORMAT_NXUNV) {
     if(PostStream)
-      Unv_PrintRegion(PostStream, Flag_Comma, numRegion, NbrHarmonics, Size, Value);
+      Unv_PrintRegion(PostStream, Comma ? 1 : 0, numRegion, NbrHarmonics,
+                      Size, Value, NXUnv_UnitFactor);
   }
   else if (Format == FORMAT_LOOP_ERROR) {
     StorePostOpResult(NbrHarmonics, Value);
@@ -1829,23 +1918,29 @@ void Format_PostValue(struct PostQuantity  *PQ_P,
         case FORMAT_VALUE_ONLY :
           break;
 	default :
-	  fprintf(PostStream, "%.16g ", Time) ;
-	  break ;
+	  fprintf(PostStream, " %.16g", Time) ;
+          if (Comma) fprintf(PostStream, "%s", Comma);
+          break ;
 	}
-	for (iRegion = 0 ; iRegion < NbrRegion ; iRegion++)
+	for (iRegion = 0 ; iRegion < NbrRegion ; iRegion++) {
 	  for (k = 0 ; k < NbrHarmonics ; k++) {
 	    if ((Format == FORMAT_FREQUENCY_TABLE ||
                  Format == FORMAT_FREQUENCY_REGION_VALUE)
-                && !(k%2) && iRegion==0) {
+                && !(k % 2) && iRegion == 0) {
 	      Freq = Current.DofData->Val_Pulsation[0] / TWO_PI ;
-	      fprintf(PostStream, "%.16g ", Freq) ;
+	      fprintf(PostStream, " %.16g", Freq) ;
+              if (Comma) fprintf(PostStream, "%s", Comma);
 	    }
-	    for(j = 0 ; j < Size ; j++)
+	    for(j = 0 ; j < Size ; j++) {
               if (Format != FORMAT_REGION_VALUE &&
-                  Format != FORMAT_FREQUENCY_REGION_VALUE)
-	      fprintf(PostStream, " %.16g",
-                      TmpValues[indexInTmpValues+iRegion].Val[MAX_DIM*k+j]) ;
+                  Format != FORMAT_FREQUENCY_REGION_VALUE) {
+                fprintf(PostStream, " %.16g",
+                        TmpValues[indexInTmpValues+iRegion].Val[MAX_DIM*k+j]) ;
+                if (Comma) fprintf(PostStream, "%s", Comma);
+              }
+            }
 	  }
+        }
 	if (Flag_NoNewLine ||
             Format == FORMAT_REGION_VALUE || Format == FORMAT_FREQUENCY_REGION_VALUE)
 	  fprintf(PostStream, " ") ;
@@ -1857,9 +1952,14 @@ void Format_PostValue(struct PostQuantity  *PQ_P,
 	  for (iRegion = 0 ; iRegion < NbrRegion ; iRegion++) {
 	    F_MHToTime0(k+iRegion, &TmpValues[indexInTmpValues+iRegion], &TmpValue,
 			k, HarmonicToTime, &TimeMH) ;
-	    if (iRegion == 0)  fprintf(PostStream, "%.16g ", TimeMH) ;
-	    for(j = 0 ; j < Size ; j++)
+	    if (iRegion == 0) {
+              fprintf(PostStream, " %.16g", TimeMH) ;
+              if (Comma) fprintf(PostStream, "%s", Comma);
+            }
+	    for(j = 0 ; j < Size ; j++) {
 	      fprintf(PostStream, " %.16g", TmpValue.Val[j]) ;
+              if (Comma) fprintf(PostStream, "%s", Comma);
+            }
 	  }
 	  fprintf(PostStream, "\n") ;
 	}
