@@ -1,10 +1,10 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <getdp@onelab.info>.
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
-#ifndef _POS_FORMULATION_H_
-#define _POS_FORMULATION_H_
+#ifndef POS_FORMULATION_H
+#define POS_FORMULATION_H
 
 #include "ProData.h"
 #include "ListUtils.h"
