@@ -1,7 +1,7 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <getdp@onelab.info>.
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 //
 // Contributor(s):
 //   Johan Gyselinck
@@ -223,9 +223,10 @@ void  Treatment_PostOperation(struct Resolution     * Resolution_P,
 
   Nbr_PostSubOperation = List_Nbr(PostOperation_P->PostSubOperation) ;
   for (i_POP = 0 ; i_POP < Nbr_PostSubOperation ; i_POP++) {
-    Message::Info("PostOperation %d/%d ", i_POP+1, Nbr_PostSubOperation) ;
     PostSubOperation_P = (struct PostSubOperation*)
       List_Pointer(PostOperation_P->PostSubOperation, i_POP) ;
+    Message::Info("PostOperation '%s' %d/%d", PostOperation_P->Name, i_POP+1,
+                  Nbr_PostSubOperation) ;
     Pos_Formulation(Formulation_P, PostProcessing_P, PostSubOperation_P) ;
   }
 
@@ -440,7 +441,7 @@ void SolvingAnalyse()
   /* Pre-processing */
   /* -------------- */
 
-  TreatmentStatus = _PRE ;
+  TreatmentStatus = STATUS_PRE ;
 
   Message::Direct("P r e - P r o c e s s i n g . . .") ;
   Message::ProgressMeter(0, 0, "Pre-processing");
@@ -467,7 +468,7 @@ void SolvingAnalyse()
                            &Resolution2_P, &DefineSystem2_P0,
                            &DofData2_P0, &DofData2_L, GeoData_L, &GeoData_P0) ;
 
-      TreatmentStatus = _PRE ;
+      TreatmentStatus = STATUS_PRE ;
       Treatment_Preprocessing(Nbr_DefineSystem2, DofData2_P0,
 			      DefineSystem2_P0, GeoData_P0) ;
 
@@ -482,7 +483,7 @@ void SolvingAnalyse()
       Current.RelativeDifference = 0. ; Current.RelaxationFactor = 1. ;
       Current.Breakpoint = -1;
 
-      TreatmentStatus = _CAL ;
+      TreatmentStatus = STATUS_CAL ;
 
       Current.NbrSystem  = Nbr_DefineSystem2 ;  /* Attention: init for Dt[] */
       Current.DofData_P0 = DofData2_P0 ;
@@ -561,7 +562,7 @@ void SolvingAnalyse()
   /* ---------- */
 
   if (Flag_CAL) {
-    TreatmentStatus = _CAL ;
+    TreatmentStatus = STATUS_CAL ;
     Message::Direct("P r o c e s s i n g . . .") ;
     Message::ProgressMeter(0, 0, "Processing");
 
@@ -608,7 +609,7 @@ void SolvingAnalyse()
   /* --------------- */
 
   if (Flag_POS) {
-    TreatmentStatus = _POS ;
+    TreatmentStatus = STATUS_POS ;
 
     Message::Direct("P o s t - P r o c e s s i n g . . .") ;
     Message::ProgressMeter(0, 0, "Post-processing");
