@@ -1,10 +1,10 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2021 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <getdp@onelab.info>.
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
-#ifndef _NUMERIC_UTILS_H_
-#define _NUMERIC_UTILS_H_
+#ifndef NUMERIC_UTILS_H
+#define NUMERIC_UTILS_H
 
 // Numerical routines implemented using either the GSL or Numerical Recipes
 double brent(double ax, double bx, double cx,
